@@ -25,7 +25,6 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.UUID;
-
 import org.apache.avro.Conversion;
 import org.apache.avro.LogicalType;
 import org.apache.avro.Schema;
@@ -34,15 +33,20 @@ import org.apache.avro.generic.GenericFixed;
 import org.apache.avro.generic.IndexedRecord;
 import org.apache.avro.util.Utf8;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.util.ReflectionUtils;
+import org.apache.parquet.Preconditions;
+import org.apache.parquet.conf.HadoopParquetConfiguration;
+import org.apache.parquet.conf.ParquetConfiguration;
 import org.apache.parquet.hadoop.api.WriteSupport;
+import org.apache.parquet.hadoop.util.ConfigurationUtil;
 import org.apache.parquet.io.api.Binary;
 import org.apache.parquet.io.api.RecordConsumer;
 import org.apache.parquet.schema.GroupType;
 import org.apache.parquet.schema.LogicalTypeAnnotation.UUIDLogicalTypeAnnotation;
 import org.apache.parquet.schema.MessageType;
 import org.apache.parquet.schema.Type;
-import org.apache.hadoop.util.ReflectionUtils;
-import org.apache.parquet.Preconditions;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * Avro implementation of {@link WriteSupport} for generic, specific, and
@@ -51,18 +55,18 @@ import org.apache.parquet.Preconditions;
  */
 public class AvroWriteSupport<T> extends WriteSupport<T> {
 
+  private static final Logger LOG = LoggerFactory.getLogger(AvroWriteSupport.class);
+
   public static final String AVRO_DATA_SUPPLIER = "parquet.avro.write.data.supplier";
 
-  public static void setAvroDataSupplier(
-      Configuration configuration, Class<? extends AvroDataSupplier> suppClass) {
+  public static void setAvroDataSupplier(Configuration configuration, Class<? extends AvroDataSupplier> suppClass) {
     configuration.set(AVRO_DATA_SUPPLIER, suppClass.getName());
   }
 
   static final String AVRO_SCHEMA = "parquet.avro.schema";
   private static final Schema MAP_KEY_SCHEMA = Schema.create(Schema.Type.STRING);
 
-  public static final String WRITE_OLD_LIST_STRUCTURE =
-      "parquet.avro.write-old-list-structure";
+  public static final String WRITE_OLD_LIST_STRUCTURE = "parquet.avro.write-old-list-structure";
   static final boolean WRITE_OLD_LIST_STRUCTURE_DEFAULT = true;
   public static final String WRITE_PARQUET_UUID = "parquet.avro.write-parquet-uuid";
   static final boolean WRITE_PARQUET_UUID_DEFAULT = false;
@@ -85,11 +89,10 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
   private GenericData model;
   private ListWriter listWriter;
 
-  public AvroWriteSupport() {
-  }
+  public AvroWriteSupport() {}
 
   /**
-   * @param schema the write parquet schema
+   * @param schema     the write parquet schema
    * @param avroSchema the write avro schema
    * @deprecated will be removed in 2.0.0
    */
@@ -101,8 +104,7 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
     this.model = null;
   }
 
-  public AvroWriteSupport(MessageType schema, Schema avroSchema,
-                          GenericData model) {
+  public AvroWriteSupport(MessageType schema, Schema avroSchema, GenericData model) {
     this.rootSchema = schema;
     this.rootAvroSchema = avroSchema;
     this.rootLogicalType = rootAvroSchema.getLogicalType();
@@ -116,7 +118,7 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
 
   /**
    * @param configuration a configuration
-   * @param schema the write schema
+   * @param schema        the write schema
    * @see org.apache.parquet.avro.AvroParquetOutputFormat#setSchema(org.apache.hadoop.mapreduce.Job, org.apache.avro.Schema)
    */
   public static void setSchema(Configuration configuration, Schema schema) {
@@ -125,17 +127,22 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
 
   @Override
   public WriteContext init(Configuration configuration) {
+    return init(new HadoopParquetConfiguration(configuration));
+  }
+
+  @Override
+  public WriteContext init(ParquetConfiguration configuration) {
     if (rootAvroSchema == null) {
       this.rootAvroSchema = new Schema.Parser().parse(configuration.get(AVRO_SCHEMA));
       this.rootSchema = new AvroSchemaConverter(configuration).convert(rootAvroSchema);
     }
 
     if (model == null) {
-      this.model = getDataModel(configuration);
+      this.model = getDataModel(configuration, rootAvroSchema);
     }
 
-    boolean writeOldListStructure = configuration.getBoolean(
-        WRITE_OLD_LIST_STRUCTURE, WRITE_OLD_LIST_STRUCTURE_DEFAULT);
+    boolean writeOldListStructure =
+        configuration.getBoolean(WRITE_OLD_LIST_STRUCTURE, WRITE_OLD_LIST_STRUCTURE_DEFAULT);
     if (writeOldListStructure) {
       this.listWriter = new TwoLevelListWriter();
     } else {
@@ -161,14 +168,11 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
   @Override
   public void write(T record) {
     if (rootLogicalType != null) {
-      Conversion<?> conversion = model.getConversionByClass(
-          record.getClass(), rootLogicalType);
+      Conversion<?> conversion = model.getConversionByClass(record.getClass(), rootLogicalType);
 
       recordConsumer.startMessage();
-      writeRecordFields(rootSchema, rootAvroSchema,
-          convert(rootAvroSchema, rootLogicalType, conversion, record));
+      writeRecordFields(rootSchema, rootAvroSchema, convert(rootAvroSchema, rootLogicalType, conversion, record));
       recordConsumer.endMessage();
-
     } else {
       recordConsumer.startMessage();
       writeRecordFields(rootSchema, rootAvroSchema, record);
@@ -176,15 +180,13 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
     }
   }
 
-  private void writeRecord(GroupType schema, Schema avroSchema,
-                           Object record) {
+  private void writeRecord(GroupType schema, Schema avroSchema, Object record) {
     recordConsumer.startGroup();
     writeRecordFields(schema, avroSchema, record);
     recordConsumer.endGroup();
   }
 
-  private void writeRecordFields(GroupType schema, Schema avroSchema,
-                                 Object record) {
+  private void writeRecordFields(GroupType schema, Schema avroSchema, Object record) {
     List<Type> fields = schema.getFields();
     List<Schema.Field> avroFields = avroSchema.getFields();
     int index = 0; // parquet ignores Avro nulls, so index may differ
@@ -206,14 +208,13 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
     }
   }
 
-  private <V> void writeMap(GroupType schema, Schema avroSchema,
-                            Map<CharSequence, V> map) {
+  private <V> void writeMap(GroupType schema, Schema avroSchema, Map<CharSequence, V> map) {
     GroupType innerGroup = schema.getType(0).asGroupType();
     Type keyType = innerGroup.getType(0);
     Type valueType = innerGroup.getType(1);
 
     recordConsumer.startGroup(); // group wrapper (original type MAP)
-    if (map.size() > 0) {
+    if (!map.isEmpty()) {
       recordConsumer.startField(MAP_REPEATED_NAME, 0);
 
       for (Map.Entry<CharSequence, V> entry : map.entrySet()) {
@@ -237,8 +238,7 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
     recordConsumer.endGroup();
   }
 
-  private void writeUnion(GroupType parquetSchema, Schema avroSchema,
-                          Object value) {
+  private void writeUnion(GroupType parquetSchema, Schema avroSchema, Object value) {
     recordConsumer.startGroup();
 
     // ResolveUnion will tell us which of the union member types to
@@ -260,8 +260,7 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
     // set of columns.
     String memberName = "member" + parquetIndex;
     recordConsumer.startField(memberName, parquetIndex);
-    writeValue(parquetGroup.getType(parquetIndex),
-               avroSchema.getTypes().get(avroIndex), value);
+    writeValue(parquetGroup.getType(parquetIndex), avroSchema.getTypes().get(avroIndex), value);
     recordConsumer.endField(memberName, parquetIndex);
 
     recordConsumer.endGroup();
@@ -271,42 +270,52 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
    * Calls an appropriate write method based on the value.
    * Value MUST not be null.
    *
-   * @param type the Parquet type
+   * @param type       the Parquet type
    * @param avroSchema the Avro schema
-   * @param value a non-null value to write
+   * @param value      a non-null value to write
    */
   private void writeValue(Type type, Schema avroSchema, Object value) {
     Schema nonNullAvroSchema = AvroSchemaConverter.getNonNull(avroSchema);
     LogicalType logicalType = nonNullAvroSchema.getLogicalType();
     if (logicalType != null) {
-      Conversion<?> conversion = model.getConversionByClass(
-          value.getClass(), logicalType);
-      writeValueWithoutConversion(type, nonNullAvroSchema,
-          convert(nonNullAvroSchema, logicalType, conversion, value));
+      Conversion<?> conversion = model.getConversionByClass(value.getClass(), logicalType);
+      writeValueWithoutConversion(
+          type, nonNullAvroSchema, convert(nonNullAvroSchema, logicalType, conversion, value));
     } else {
       writeValueWithoutConversion(type, nonNullAvroSchema, value);
     }
   }
 
-  private <D> Object convert(Schema schema, LogicalType logicalType,
-                             Conversion<D> conversion, Object datum) {
+  private <D> Object convert(Schema schema, LogicalType logicalType, Conversion<D> conversion, Object datum) {
     if (conversion == null) {
       return datum;
     }
     Class<D> fromClass = conversion.getConvertedType();
     switch (schema.getType()) {
-      case RECORD:  return conversion.toRecord(fromClass.cast(datum), schema, logicalType);
-      case ENUM:    return conversion.toEnumSymbol(fromClass.cast(datum), schema, logicalType);
-      case ARRAY:   return conversion.toArray(fromClass.cast(datum), schema, logicalType);
-      case MAP:     return conversion.toMap(fromClass.cast(datum), schema, logicalType);
-      case FIXED:   return conversion.toFixed(fromClass.cast(datum), schema, logicalType);
-      case STRING:  return conversion.toCharSequence(fromClass.cast(datum), schema, logicalType);
-      case BYTES:   return conversion.toBytes(fromClass.cast(datum), schema, logicalType);
-      case INT:     return conversion.toInt(fromClass.cast(datum), schema, logicalType);
-      case LONG:    return conversion.toLong(fromClass.cast(datum), schema, logicalType);
-      case FLOAT:   return conversion.toFloat(fromClass.cast(datum), schema, logicalType);
-      case DOUBLE:  return conversion.toDouble(fromClass.cast(datum), schema, logicalType);
-      case BOOLEAN: return conversion.toBoolean(fromClass.cast(datum), schema, logicalType);
+      case RECORD:
+        return conversion.toRecord(fromClass.cast(datum), schema, logicalType);
+      case ENUM:
+        return conversion.toEnumSymbol(fromClass.cast(datum), schema, logicalType);
+      case ARRAY:
+        return conversion.toArray(fromClass.cast(datum), schema, logicalType);
+      case MAP:
+        return conversion.toMap(fromClass.cast(datum), schema, logicalType);
+      case FIXED:
+        return conversion.toFixed(fromClass.cast(datum), schema, logicalType);
+      case STRING:
+        return conversion.toCharSequence(fromClass.cast(datum), schema, logicalType);
+      case BYTES:
+        return conversion.toBytes(fromClass.cast(datum), schema, logicalType);
+      case INT:
+        return conversion.toInt(fromClass.cast(datum), schema, logicalType);
+      case LONG:
+        return conversion.toLong(fromClass.cast(datum), schema, logicalType);
+      case FLOAT:
+        return conversion.toFloat(fromClass.cast(datum), schema, logicalType);
+      case DOUBLE:
+        return conversion.toDouble(fromClass.cast(datum), schema, logicalType);
+      case BOOLEAN:
+        return conversion.toBoolean(fromClass.cast(datum), schema, logicalType);
     }
     return datum;
   }
@@ -315,9 +324,9 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
    * Calls an appropriate write method based on the value.
    * Value must not be null and the schema must not be nullable.
    *
-   * @param type a Parquet type
+   * @param type       a Parquet type
    * @param avroSchema a non-nullable Avro schema
-   * @param value a non-null value to write
+   * @param value      a non-null value to write
    */
   @SuppressWarnings("unchecked")
   private void writeValueWithoutConversion(Type type, Schema avroSchema, Object value) {
@@ -400,19 +409,37 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
     return Binary.fromCharSequence(value.toString());
   }
 
-  private static GenericData getDataModel(Configuration conf) {
-    Class<? extends AvroDataSupplier> suppClass = conf.getClass(
-        AVRO_DATA_SUPPLIER, SpecificDataSupplier.class, AvroDataSupplier.class);
-    return ReflectionUtils.newInstance(suppClass, conf).get();
+  private static GenericData getDataModel(ParquetConfiguration conf, Schema schema) {
+    if (conf.get(AVRO_DATA_SUPPLIER) == null && schema != null) {
+      GenericData modelForSchema;
+      try {
+        modelForSchema = AvroRecordConverter.getModelForSchema(schema);
+      } catch (Exception e) {
+        LOG.warn(
+            String.format(
+                "Failed to derive data model for Avro schema %s. Parquet will use default "
+                    + "SpecificData model for writing to sink.",
+                schema),
+            e);
+        modelForSchema = null;
+      }
+
+      if (modelForSchema != null) {
+        return modelForSchema;
+      }
+    }
+
+    Class<? extends AvroDataSupplier> suppClass =
+        conf.getClass(AVRO_DATA_SUPPLIER, SpecificDataSupplier.class, AvroDataSupplier.class);
+    return ReflectionUtils.newInstance(suppClass, ConfigurationUtil.createHadoopConfiguration(conf))
+        .get();
   }
 
   private abstract class ListWriter {
 
-    protected abstract void writeCollection(
-        GroupType type, Schema schema, Collection<?> collection);
+    protected abstract void writeCollection(GroupType type, Schema schema, Collection<?> collection);
 
-    protected abstract void writeObjectArray(
-        GroupType type, Schema schema, Object[] array);
+    protected abstract void writeObjectArray(GroupType type, Schema schema, Object[] array);
 
     protected abstract void startArray();
 
@@ -424,15 +451,14 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
         writeCollection(schema, avroSchema, (Collection) value);
       } else {
         Class<?> arrayClass = value.getClass();
-        Preconditions.checkArgument(arrayClass.isArray(),
-            "Cannot write unless collection or array: %s", arrayClass.getName());
+        Preconditions.checkArgument(
+            arrayClass.isArray(), "Cannot write unless collection or array: %s", arrayClass.getName());
         writeJavaArray(schema, avroSchema, arrayClass, value);
       }
       recordConsumer.endGroup();
     }
 
-    public void writeJavaArray(GroupType schema, Schema avroSchema,
-                               Class<?> arrayClass, Object value) {
+    public void writeJavaArray(GroupType schema, Schema avroSchema, Class<?> arrayClass, Object value) {
       Class<?> elementClass = arrayClass.getComponentType();
 
       if (!elementClass.isPrimitive()) {
@@ -442,8 +468,8 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
 
       switch (avroSchema.getElementType().getType()) {
         case BOOLEAN:
-          Preconditions.checkArgument(elementClass == boolean.class,
-              "Cannot write as boolean array: %s", arrayClass.getName());
+          Preconditions.checkArgument(
+              elementClass == boolean.class, "Cannot write as boolean array: %s", arrayClass.getName());
           writeBooleanArray((boolean[]) value);
           break;
         case INT:
@@ -456,28 +482,27 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
           } else if (elementClass == int.class) {
             writeIntArray((int[]) value);
           } else {
-            throw new IllegalArgumentException(
-                "Cannot write as an int array: " + arrayClass.getName());
+            throw new IllegalArgumentException("Cannot write as an int array: " + arrayClass.getName());
           }
           break;
         case LONG:
-          Preconditions.checkArgument(elementClass == long.class,
-              "Cannot write as long array: %s", arrayClass.getName());
+          Preconditions.checkArgument(
+              elementClass == long.class, "Cannot write as long array: %s", arrayClass.getName());
           writeLongArray((long[]) value);
           break;
         case FLOAT:
-          Preconditions.checkArgument(elementClass == float.class,
-              "Cannot write as float array: %s", arrayClass.getName());
+          Preconditions.checkArgument(
+              elementClass == float.class, "Cannot write as float array: %s", arrayClass.getName());
           writeFloatArray((float[]) value);
           break;
         case DOUBLE:
-          Preconditions.checkArgument(elementClass == double.class,
-              "Cannot write as double array: %s", arrayClass.getName());
+          Preconditions.checkArgument(
+              elementClass == double.class, "Cannot write as double array: %s", arrayClass.getName());
           writeDoubleArray((double[]) value);
           break;
         default:
-          throw new IllegalArgumentException("Cannot write " +
-              avroSchema.getElementType() + " array: " + arrayClass.getName());
+          throw new IllegalArgumentException(
+              "Cannot write " + avroSchema.getElementType() + " array: " + arrayClass.getName());
       }
     }
 
@@ -567,8 +592,7 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
    */
   private class TwoLevelListWriter extends ListWriter {
     @Override
-    public void writeCollection(GroupType schema, Schema avroSchema,
-                                Collection<?> array) {
+    public void writeCollection(GroupType schema, Schema avroSchema, Collection<?> array) {
       if (!array.isEmpty()) {
         recordConsumer.startField(OLD_LIST_REPEATED_NAME, 0);
         try {
@@ -577,24 +601,21 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
           }
         } catch (NullPointerException e) {
           // find the null element and throw a better error message
-          final int idx =
-              Arrays.asList(array.toArray(new Object[0])).indexOf(null);
+          final int idx = Arrays.asList(array.toArray(new Object[0])).indexOf(null);
           if (idx < 0) {
             // no element was null, throw the original exception
             throw e;
           }
-          throw new NullPointerException(
-              "Array contains a null element at " + idx + ". "
-                  + "Set parquet.avro.write-old-list-structure=false to turn "
-                  + "on support for arrays with null elements.");
+          throw new NullPointerException("Array contains a null element at " + idx + ". "
+              + "Set parquet.avro.write-old-list-structure=false to turn "
+              + "on support for arrays with null elements.");
         }
         recordConsumer.endField(OLD_LIST_REPEATED_NAME, 0);
       }
     }
 
     @Override
-    protected void writeObjectArray(GroupType type, Schema schema,
-                                    Object[] array) {
+    protected void writeObjectArray(GroupType type, Schema schema, Object[] array) {
       if (array.length > 0) {
         recordConsumer.startField(OLD_LIST_REPEATED_NAME, 0);
         try {
@@ -608,10 +629,9 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
             // no element was null, throw the original exception
             throw e;
           }
-          throw new NullPointerException(
-              "Array contains a null element at " + idx + ". " +
-              "Set parquet.avro.write-old-list-structure=false to turn " +
-              "on support for arrays with null elements.");
+          throw new NullPointerException("Array contains a null element at " + idx + ". "
+              + "Set parquet.avro.write-old-list-structure=false to turn "
+              + "on support for arrays with null elements.");
         }
         recordConsumer.endField(OLD_LIST_REPEATED_NAME, 0);
       }
@@ -631,7 +651,7 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
   private class ThreeLevelListWriter extends ListWriter {
     @Override
     protected void writeCollection(GroupType type, Schema schema, Collection<?> collection) {
-      if (collection.size() > 0) {
+      if (!collection.isEmpty()) {
         recordConsumer.startField(LIST_REPEATED_NAME, 0);
         GroupType repeatedType = type.getType(0).asGroupType();
         Type elementType = repeatedType.getType(0);
@@ -642,8 +662,7 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
             writeValue(elementType, schema.getElementType(), element);
             recordConsumer.endField(LIST_ELEMENT_NAME, 0);
           } else if (!elementType.isRepetition(Type.Repetition.OPTIONAL)) {
-            throw new RuntimeException(
-                "Null list element for " + schema.getName());
+            throw new RuntimeException("Null list element for " + schema.getName());
           }
           recordConsumer.endGroup();
         }
@@ -652,8 +671,7 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
     }
 
     @Override
-    protected void writeObjectArray(GroupType type, Schema schema,
-                                    Object[] array) {
+    protected void writeObjectArray(GroupType type, Schema schema, Object[] array) {
       if (array.length > 0) {
         recordConsumer.startField(LIST_REPEATED_NAME, 0);
         GroupType repeatedType = type.getType(0).asGroupType();
@@ -665,8 +683,7 @@ public class AvroWriteSupport<T> extends WriteSupport<T> {
             writeValue(elementType, schema.getElementType(), element);
             recordConsumer.endField(LIST_ELEMENT_NAME, 0);
           } else if (!elementType.isRepetition(Type.Repetition.OPTIONAL)) {
-            throw new RuntimeException(
-                "Null list element for " + schema.getName());
+            throw new RuntimeException("Null list element for " + schema.getName());
           }
           recordConsumer.endGroup();
         }
