@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -19,12 +19,11 @@
 package org.apache.parquet.column.values.dictionary;
 
 import static org.apache.parquet.bytes.BytesUtils.readIntLittleEndian;
-import static org.apache.parquet.column.Encoding.PLAIN_DICTIONARY;
 import static org.apache.parquet.column.Encoding.PLAIN;
+import static org.apache.parquet.column.Encoding.PLAIN_DICTIONARY;
 
 import java.io.IOException;
 import java.nio.ByteBuffer;
-
 import org.apache.parquet.Preconditions;
 import org.apache.parquet.bytes.ByteBufferInputStream;
 import org.apache.parquet.column.Dictionary;
@@ -38,7 +37,6 @@ import org.apache.parquet.io.api.Binary;
 
 /**
  * a simple implementation of dictionary for plain encoded values
- *
  */
 public abstract class PlainValuesDictionary extends Dictionary {
 
@@ -48,9 +46,9 @@ public abstract class PlainValuesDictionary extends Dictionary {
    */
   protected PlainValuesDictionary(DictionaryPage dictionaryPage) throws IOException {
     super(dictionaryPage.getEncoding());
-    if (dictionaryPage.getEncoding() != PLAIN_DICTIONARY
-        && dictionaryPage.getEncoding() != PLAIN) {
-      throw new ParquetDecodingException("Dictionary data encoding type not supported: " + dictionaryPage.getEncoding());
+    if (dictionaryPage.getEncoding() != PLAIN_DICTIONARY && dictionaryPage.getEncoding() != PLAIN) {
+      throw new ParquetDecodingException(
+          "Dictionary data encoding type not supported: " + dictionaryPage.getEncoding());
     }
   }
 
@@ -63,7 +61,7 @@ public abstract class PlainValuesDictionary extends Dictionary {
 
     /**
      * Decodes {@link Binary} values from a {@link DictionaryPage}.
-     *
+     * <p>
      * Values are read as length-prefixed values with a 4-byte little-endian
      * length.
      *
@@ -76,14 +74,14 @@ public abstract class PlainValuesDictionary extends Dictionary {
 
     /**
      * Decodes {@link Binary} values from a {@link DictionaryPage}.
-     *
+     * <p>
      * If the given {@code length} is null, the values will be read as length-
      * prefixed values with a 4-byte little-endian length. If length is not
      * null, it will be used as the length for all fixed-length {@code Binary}
      * values read from the page.
      *
      * @param dictionaryPage a {@code DictionaryPage} of encoded binary values
-     * @param length a fixed length of binary arrays, or null if not fixed
+     * @param length         a fixed length of binary arrays, or null if not fixed
      * @throws IOException if there is an exception while decoding the dictionary page
      */
     public PlainBinaryDictionary(DictionaryPage dictionaryPage, Integer length) throws IOException {
@@ -105,12 +103,10 @@ public abstract class PlainValuesDictionary extends Dictionary {
         }
       } else {
         // dictionary values are stored as fixed-length arrays
-        Preconditions.checkArgument(length > 0,
-            "Invalid byte array length: %s", length);
+        Preconditions.checkArgument(length > 0, "Invalid byte array length: %s", length);
         for (int i = 0; i < binaryDictionaryContent.length; i++) {
           // wrap the content in a Binary
-          binaryDictionaryContent[i] = Binary.fromConstantByteBuffer(
-              dictionaryBytes, offset, length);
+          binaryDictionaryContent[i] = Binary.fromConstantByteBuffer(dictionaryBytes, offset, length);
           // increment to the next value
           offset += length;
         }
@@ -135,7 +131,6 @@ public abstract class PlainValuesDictionary extends Dictionary {
     public int getMaxId() {
       return binaryDictionaryContent.length - 1;
     }
-
   }
 
   /**
@@ -178,7 +173,6 @@ public abstract class PlainValuesDictionary extends Dictionary {
     public int getMaxId() {
       return longDictionaryContent.length - 1;
     }
-
   }
 
   /**
@@ -221,7 +215,6 @@ public abstract class PlainValuesDictionary extends Dictionary {
     public int getMaxId() {
       return doubleDictionaryContent.length - 1;
     }
-
   }
 
   /**
@@ -264,7 +257,6 @@ public abstract class PlainValuesDictionary extends Dictionary {
     public int getMaxId() {
       return intDictionaryContent.length - 1;
     }
-
   }
 
   /**
@@ -307,7 +299,5 @@ public abstract class PlainValuesDictionary extends Dictionary {
     public int getMaxId() {
       return floatDictionaryContent.length - 1;
     }
-
   }
-
 }
