@@ -22,7 +22,6 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
-
 import org.apache.parquet.filter2.predicate.Operators.Column;
 import org.apache.parquet.hadoop.metadata.ColumnPath;
 import org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName;
@@ -30,39 +29,39 @@ import org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName;
 /**
  * Contains all valid mappings from class -&gt; parquet type (and vice versa) for use in
  * {@link FilterPredicate}s
- *
+ * <p>
  * This is a bit ugly, but it allows us to provide good error messages at runtime
  * when there are type mismatches.
- *
+ * <p>
  * TODO: this has some overlap with {@link PrimitiveTypeName#javaType}
  * TODO: (https://issues.apache.org/jira/browse/PARQUET-30)
  */
 public class ValidTypeMap {
-  private ValidTypeMap() { }
+  private ValidTypeMap() {}
 
   // classToParquetType and parquetTypeToClass are used as a bi-directional map
-  private static final Map<Class<?>, Set<PrimitiveTypeName>> classToParquetType = new HashMap<Class<?>, Set<PrimitiveTypeName>>();
-  private static final Map<PrimitiveTypeName, Set<Class<?>>> parquetTypeToClass = new HashMap<PrimitiveTypeName, Set<Class<?>>>();
+  private static final Map<Class<?>, Set<PrimitiveTypeName>> classToParquetType = new HashMap<>();
+  private static final Map<PrimitiveTypeName, Set<Class<?>>> parquetTypeToClass = new HashMap<>();
 
   // set up the mapping in both directions
   private static void add(Class<?> c, PrimitiveTypeName p) {
     Set<PrimitiveTypeName> descriptors = classToParquetType.get(c);
     if (descriptors == null) {
-      descriptors = new HashSet<PrimitiveTypeName>();
+      descriptors = new HashSet<>();
       classToParquetType.put(c, descriptors);
     }
     descriptors.add(p);
 
     Set<Class<?>> classes = parquetTypeToClass.get(p);
     if (classes == null) {
-      classes = new HashSet<Class<?>>();
+      classes = new HashSet<>();
       parquetTypeToClass.put(p, classes);
     }
     classes.add(c);
   }
 
   static {
-    for (PrimitiveTypeName t: PrimitiveTypeName.values()) {
+    for (PrimitiveTypeName t : PrimitiveTypeName.values()) {
       Class<?> c = t.javaType;
 
       if (c.isPrimitive()) {
@@ -77,13 +76,13 @@ public class ValidTypeMap {
    * Asserts that foundColumn was declared as a type that is compatible with the type for this column found
    * in the schema of the parquet file.
    *
-   * @throws java.lang.IllegalArgumentException if the types do not align
-   *
-   * @param foundColumn the column as declared by the user
+   * @param foundColumn   the column as declared by the user
    * @param primitiveType the primitive type according to the schema
-   * @param <T> the java Type of values in the column, must be Comparable
+   * @param <T>           the java Type of values in the column, must be Comparable
+   * @throws java.lang.IllegalArgumentException if the types do not align
    */
-  public static <T extends Comparable<T>> void assertTypeValid(Column<T> foundColumn, PrimitiveTypeName primitiveType) {
+  public static <T extends Comparable<T>> void assertTypeValid(
+      Column<T> foundColumn, PrimitiveTypeName primitiveType) {
     Class<T> foundColumnType = foundColumn.getColumnType();
     ColumnPath columnPath = foundColumn.getColumnPath();
 
@@ -91,8 +90,7 @@ public class ValidTypeMap {
 
     if (validTypeDescriptors == null) {
       StringBuilder message = new StringBuilder();
-      message
-          .append("Column ")
+      message.append("Column ")
           .append(columnPath.toDotString())
           .append(" was declared as type: ")
           .append(foundColumnType.getName())
@@ -100,9 +98,7 @@ public class ValidTypeMap {
 
       Set<Class<?>> supportedTypes = parquetTypeToClass.get(primitiveType);
       if (supportedTypes != null) {
-        message
-          .append(" Supported types for this column are: ")
-          .append(supportedTypes);
+        message.append(" Supported types for this column are: ").append(supportedTypes);
       } else {
         message.append(" There are no supported types for columns of " + primitiveType);
       }
@@ -111,8 +107,7 @@ public class ValidTypeMap {
 
     if (!validTypeDescriptors.contains(primitiveType)) {
       StringBuilder message = new StringBuilder();
-      message
-          .append("FilterPredicate column: ")
+      message.append("FilterPredicate column: ")
           .append(columnPath.toDotString())
           .append("'s declared type (")
           .append(foundColumnType.getName())
