@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
+ * <p>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p>
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,11 +18,21 @@
  */
 package org.apache.parquet.column.impl;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
+import java.lang.reflect.Field;
+import java.nio.ByteBuffer;
+import java.util.ArrayList;
+import java.util.List;
 import org.apache.parquet.CorruptDeltaByteArrays;
 import org.apache.parquet.SemanticVersion;
 import org.apache.parquet.VersionParser.ParsedVersion;
 import org.apache.parquet.bytes.ByteBufferInputStream;
 import org.apache.parquet.bytes.BytesInput;
+import org.apache.parquet.bytes.HeapByteBufferAllocator;
 import org.apache.parquet.column.ColumnDescriptor;
 import org.apache.parquet.column.Encoding;
 import org.apache.parquet.column.ParquetProperties;
@@ -37,34 +47,30 @@ import org.apache.parquet.io.api.PrimitiveConverter;
 import org.apache.parquet.schema.PrimitiveType;
 import org.junit.Assert;
 import org.junit.Test;
-import org.apache.parquet.bytes.HeapByteBufferAllocator;
-
-import java.lang.reflect.Field;
-import java.nio.ByteBuffer;
-import java.util.ArrayList;
-import java.util.List;
-
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
 
 public class TestCorruptDeltaByteArrays {
   @Test
   public void testCorruptDeltaByteArrayVerisons() {
-    assertTrue(CorruptDeltaByteArrays.requiresSequentialReads("parquet-mr version 1.6.0 (build abcd)", Encoding.DELTA_BYTE_ARRAY));
+    assertTrue(CorruptDeltaByteArrays.requiresSequentialReads(
+        "parquet-mr version 1.6.0 (build abcd)", Encoding.DELTA_BYTE_ARRAY));
     assertTrue(CorruptDeltaByteArrays.requiresSequentialReads((String) null, Encoding.DELTA_BYTE_ARRAY));
     assertTrue(CorruptDeltaByteArrays.requiresSequentialReads((ParsedVersion) null, Encoding.DELTA_BYTE_ARRAY));
     assertTrue(CorruptDeltaByteArrays.requiresSequentialReads((SemanticVersion) null, Encoding.DELTA_BYTE_ARRAY));
-    assertTrue(CorruptDeltaByteArrays.requiresSequentialReads("parquet-mr version 1.8.0-SNAPSHOT (build abcd)", Encoding.DELTA_BYTE_ARRAY));
-    assertFalse(CorruptDeltaByteArrays.requiresSequentialReads("parquet-mr version 1.6.0 (build abcd)", Encoding.DELTA_BINARY_PACKED));
+    assertTrue(CorruptDeltaByteArrays.requiresSequentialReads(
+        "parquet-mr version 1.8.0-SNAPSHOT (build abcd)", Encoding.DELTA_BYTE_ARRAY));
+    assertFalse(CorruptDeltaByteArrays.requiresSequentialReads(
+        "parquet-mr version 1.6.0 (build abcd)", Encoding.DELTA_BINARY_PACKED));
     assertFalse(CorruptDeltaByteArrays.requiresSequentialReads((String) null, Encoding.DELTA_LENGTH_BYTE_ARRAY));
     assertFalse(CorruptDeltaByteArrays.requiresSequentialReads((ParsedVersion) null, Encoding.PLAIN));
     assertFalse(CorruptDeltaByteArrays.requiresSequentialReads((SemanticVersion) null, Encoding.RLE));
-    assertFalse(CorruptDeltaByteArrays.requiresSequentialReads("parquet-mr version 1.8.0-SNAPSHOT (build abcd)", Encoding.RLE_DICTIONARY));
-    assertFalse(CorruptDeltaByteArrays.requiresSequentialReads("parquet-mr version 1.8.0-SNAPSHOT (build abcd)", Encoding.PLAIN_DICTIONARY));
-    assertFalse(CorruptDeltaByteArrays.requiresSequentialReads("parquet-mr version 1.8.0-SNAPSHOT (build abcd)", Encoding.BIT_PACKED));
-    assertFalse(CorruptDeltaByteArrays.requiresSequentialReads("parquet-mr version 1.8.0 (build abcd)", Encoding.DELTA_BYTE_ARRAY));
+    assertFalse(CorruptDeltaByteArrays.requiresSequentialReads(
+        "parquet-mr version 1.8.0-SNAPSHOT (build abcd)", Encoding.RLE_DICTIONARY));
+    assertFalse(CorruptDeltaByteArrays.requiresSequentialReads(
+        "parquet-mr version 1.8.0-SNAPSHOT (build abcd)", Encoding.PLAIN_DICTIONARY));
+    assertFalse(CorruptDeltaByteArrays.requiresSequentialReads(
+        "parquet-mr version 1.8.0-SNAPSHOT (build abcd)", Encoding.BIT_PACKED));
+    assertFalse(CorruptDeltaByteArrays.requiresSequentialReads(
+        "parquet-mr version 1.8.0 (build abcd)", Encoding.DELTA_BYTE_ARRAY));
   }
 
   @Test
@@ -187,14 +193,13 @@ public class TestCorruptDeltaByteArrays {
 
   @Test
   public void testColumnReaderImplWithCorruptPage() throws Exception {
-    ColumnDescriptor column = new ColumnDescriptor(
-        new String[] {"s"}, PrimitiveType.PrimitiveTypeName.BINARY, 0, 0);
+    ColumnDescriptor column =
+        new ColumnDescriptor(new String[] {"s"}, PrimitiveType.PrimitiveTypeName.BINARY, 0, 0);
     MemPageStore pages = new MemPageStore(0);
     PageWriter memWriter = pages.getPageWriter(column);
 
-    ParquetProperties parquetProps = ParquetProperties.builder()
-        .withDictionaryEncoding(false)
-        .build();
+    ParquetProperties parquetProps =
+        ParquetProperties.builder().withDictionaryEncoding(false).build();
 
     // get generic repetition and definition level bytes to use for pages
     ValuesWriter rdValues = parquetProps.newDefinitionLevelWriter(column);
@@ -212,7 +217,8 @@ public class TestCorruptDeltaByteArrays {
       values.add(lastValue);
     }
 
-    memWriter.writePage(BytesInput.concat(rd, rd, writer.getBytes()),
+    memWriter.writePage(
+        BytesInput.concat(rd, rd, writer.getBytes()),
         10, /* number of values in the page */
         new BinaryStatistics(),
         rdValues.getEncoding(),
@@ -228,7 +234,8 @@ public class TestCorruptDeltaByteArrays {
       values.add(value);
     }
 
-    memWriter.writePage(BytesInput.concat(rd, rd, writer.getBytes()),
+    memWriter.writePage(
+        BytesInput.concat(rd, rd, writer.getBytes()),
         10, /* number of values in the page */
         new BinaryStatistics(),
         rdValues.getEncoding(),
@@ -245,8 +252,7 @@ public class TestCorruptDeltaByteArrays {
     };
 
     ColumnReaderImpl columnReader = new ColumnReaderImpl(
-        column, pages.getPageReader(column), converter,
-        new ParsedVersion("parquet-mr", "1.6.0", "abcd"));
+        column, pages.getPageReader(column), converter, new ParsedVersion("parquet-mr", "1.6.0", "abcd"));
 
     while (actualValues.size() < columnReader.getTotalValueCount()) {
       columnReader.writeCurrentValueToConverter();
