@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -30,17 +30,19 @@ import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.FLOAT;
 import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.INT32;
 import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.INT64;
 import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.INT96;
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 
 import java.nio.ByteBuffer;
 import java.util.Locale;
-
-import org.junit.Test;
 import org.apache.parquet.io.api.Binary;
 import org.apache.parquet.schema.OriginalType;
 import org.apache.parquet.schema.PrimitiveType;
-import org.apache.parquet.schema.Types;
 import org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName;
+import org.apache.parquet.schema.Types;
+import org.junit.Test;
 
 public class TestStatistics {
   private int[] integerArray;
@@ -75,7 +77,7 @@ public class TestStatistics {
     integerArray = new int[] {1, 3, 14, 54, 66, 8, 0, 23, 54};
     IntStatistics stats = new IntStatistics();
 
-    for (int i: integerArray) {
+    for (int i : integerArray) {
       stats.updateStats(i);
     }
     assertEquals(stats.getMax(), 66);
@@ -85,7 +87,7 @@ public class TestStatistics {
     integerArray = new int[] {-11, 3, -14, 54, -66, 8, 0, -23, 54};
     IntStatistics statsNeg = new IntStatistics();
 
-    for (int i: integerArray) {
+    for (int i : integerArray) {
       statsNeg.updateStats(i);
     }
     assertEquals(statsNeg.getMax(), 54);
@@ -102,8 +104,16 @@ public class TestStatistics {
     byte[] intMaxBytes = statsNeg.getMaxBytes();
     byte[] intMinBytes = statsNeg.getMinBytes();
 
-    assertEquals(ByteBuffer.wrap(intMaxBytes).order(java.nio.ByteOrder.LITTLE_ENDIAN).getInt(), 54);
-    assertEquals(ByteBuffer.wrap(intMinBytes).order(java.nio.ByteOrder.LITTLE_ENDIAN).getInt(), -66);
+    assertEquals(
+        ByteBuffer.wrap(intMaxBytes)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getInt(),
+        54);
+    assertEquals(
+        ByteBuffer.wrap(intMinBytes)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getInt(),
+        -66);
 
     IntStatistics statsFromBytes = new IntStatistics();
     statsFromBytes.setMinMaxFromBytes(intMinBytes, intMaxBytes);
@@ -114,7 +124,7 @@ public class TestStatistics {
     integerArray = new int[] {Integer.MAX_VALUE, Integer.MIN_VALUE};
     IntStatistics minMaxValues = new IntStatistics();
 
-    for (int i: integerArray) {
+    for (int i : integerArray) {
       minMaxValues.updateStats(i);
     }
     assertEquals(minMaxValues.getMax(), Integer.MAX_VALUE);
@@ -124,10 +134,18 @@ public class TestStatistics {
     byte[] intMaxBytesMinMax = minMaxValues.getMaxBytes();
     byte[] intMinBytesMinMax = minMaxValues.getMinBytes();
 
-    assertEquals(ByteBuffer.wrap(intMaxBytesMinMax).order(java.nio.ByteOrder.LITTLE_ENDIAN).getInt(), Integer.MAX_VALUE);
-    assertEquals(ByteBuffer.wrap(intMinBytesMinMax).order(java.nio.ByteOrder.LITTLE_ENDIAN).getInt(), Integer.MIN_VALUE);
+    assertEquals(
+        ByteBuffer.wrap(intMaxBytesMinMax)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getInt(),
+        Integer.MAX_VALUE);
+    assertEquals(
+        ByteBuffer.wrap(intMinBytesMinMax)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getInt(),
+        Integer.MIN_VALUE);
 
-    IntStatistics statsFromBytesMinMax= new IntStatistics();
+    IntStatistics statsFromBytesMinMax = new IntStatistics();
     statsFromBytesMinMax.setMinMaxFromBytes(intMinBytesMinMax, intMaxBytesMinMax);
 
     assertEquals(statsFromBytesMinMax.getMax(), Integer.MAX_VALUE);
@@ -143,7 +161,7 @@ public class TestStatistics {
     longArray = new long[] {9, 39, 99, 3, 0, 12, 1000, 65, 542};
     LongStatistics stats = new LongStatistics();
 
-    for (long l: longArray) {
+    for (long l : longArray) {
       stats.updateStats(l);
     }
     assertEquals(stats.getMax(), 1000);
@@ -153,7 +171,7 @@ public class TestStatistics {
     longArray = new long[] {-101, 993, -9914, 54, -9, 89, 0, -23, 90};
     LongStatistics statsNeg = new LongStatistics();
 
-    for (long l: longArray) {
+    for (long l : longArray) {
       statsNeg.updateStats(l);
     }
     assertEquals(statsNeg.getMax(), 993);
@@ -170,8 +188,16 @@ public class TestStatistics {
     byte[] longMaxBytes = statsNeg.getMaxBytes();
     byte[] longMinBytes = statsNeg.getMinBytes();
 
-    assertEquals(ByteBuffer.wrap(longMaxBytes).order(java.nio.ByteOrder.LITTLE_ENDIAN).getLong(), 993);
-    assertEquals(ByteBuffer.wrap(longMinBytes).order(java.nio.ByteOrder.LITTLE_ENDIAN).getLong(), -9914);
+    assertEquals(
+        ByteBuffer.wrap(longMaxBytes)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getLong(),
+        993);
+    assertEquals(
+        ByteBuffer.wrap(longMinBytes)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getLong(),
+        -9914);
 
     LongStatistics statsFromBytes = new LongStatistics();
     statsFromBytes.setMinMaxFromBytes(longMinBytes, longMaxBytes);
@@ -182,7 +208,7 @@ public class TestStatistics {
     longArray = new long[] {Long.MAX_VALUE, Long.MIN_VALUE};
     LongStatistics minMaxValues = new LongStatistics();
 
-    for (long l: longArray) {
+    for (long l : longArray) {
       minMaxValues.updateStats(l);
     }
     assertEquals(minMaxValues.getMax(), Long.MAX_VALUE);
@@ -192,10 +218,18 @@ public class TestStatistics {
     byte[] longMaxBytesMinMax = minMaxValues.getMaxBytes();
     byte[] longMinBytesMinMax = minMaxValues.getMinBytes();
 
-    assertEquals(ByteBuffer.wrap(longMaxBytesMinMax).order(java.nio.ByteOrder.LITTLE_ENDIAN).getLong(), Long.MAX_VALUE);
-    assertEquals(ByteBuffer.wrap(longMinBytesMinMax).order(java.nio.ByteOrder.LITTLE_ENDIAN).getLong(), Long.MIN_VALUE);
+    assertEquals(
+        ByteBuffer.wrap(longMaxBytesMinMax)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getLong(),
+        Long.MAX_VALUE);
+    assertEquals(
+        ByteBuffer.wrap(longMinBytesMinMax)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getLong(),
+        Long.MIN_VALUE);
 
-    LongStatistics statsFromBytesMinMax= new LongStatistics();
+    LongStatistics statsFromBytesMinMax = new LongStatistics();
     statsFromBytesMinMax.setMinMaxFromBytes(longMinBytesMinMax, longMaxBytesMinMax);
 
     assertEquals(statsFromBytesMinMax.getMax(), Long.MAX_VALUE);
@@ -211,7 +245,7 @@ public class TestStatistics {
     floatArray = new float[] {1.5f, 44.5f, 412.99f, 0.65f, 5.6f, 100.6f, 0.0001f, 23.0f, 553.6f};
     FloatStatistics stats = new FloatStatistics();
 
-    for (float f: floatArray) {
+    for (float f : floatArray) {
       stats.updateStats(f);
     }
     assertEquals(stats.getMax(), 553.6f, 1e-10);
@@ -221,7 +255,7 @@ public class TestStatistics {
     floatArray = new float[] {-1.5f, -44.5f, -412.99f, 0.65f, -5.6f, -100.6f, 0.0001f, -23.0f, -3.6f};
     FloatStatistics statsNeg = new FloatStatistics();
 
-    for (float f: floatArray) {
+    for (float f : floatArray) {
       statsNeg.updateStats(f);
     }
     assertEquals(statsNeg.getMax(), 0.65f, 1e-10);
@@ -238,8 +272,18 @@ public class TestStatistics {
     byte[] floatMaxBytes = statsNeg.getMaxBytes();
     byte[] floatMinBytes = statsNeg.getMinBytes();
 
-    assertEquals(ByteBuffer.wrap(floatMaxBytes).order(java.nio.ByteOrder.LITTLE_ENDIAN).getFloat(), 0.65f, 1e-10);
-    assertEquals(ByteBuffer.wrap(floatMinBytes).order(java.nio.ByteOrder.LITTLE_ENDIAN).getFloat(), -412.99f, 1e-10);
+    assertEquals(
+        ByteBuffer.wrap(floatMaxBytes)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getFloat(),
+        0.65f,
+        1e-10);
+    assertEquals(
+        ByteBuffer.wrap(floatMinBytes)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getFloat(),
+        -412.99f,
+        1e-10);
 
     FloatStatistics statsFromBytes = new FloatStatistics();
     statsFromBytes.setMinMaxFromBytes(floatMinBytes, floatMaxBytes);
@@ -250,7 +294,7 @@ public class TestStatistics {
     floatArray = new float[] {Float.MAX_VALUE, Float.MIN_VALUE};
     FloatStatistics minMaxValues = new FloatStatistics();
 
-    for (float f: floatArray) {
+    for (float f : floatArray) {
       minMaxValues.updateStats(f);
     }
     assertEquals(minMaxValues.getMax(), Float.MAX_VALUE, 1e-10);
@@ -260,10 +304,20 @@ public class TestStatistics {
     byte[] floatMaxBytesMinMax = minMaxValues.getMaxBytes();
     byte[] floatMinBytesMinMax = minMaxValues.getMinBytes();
 
-    assertEquals(ByteBuffer.wrap(floatMaxBytesMinMax).order(java.nio.ByteOrder.LITTLE_ENDIAN).getFloat(), Float.MAX_VALUE, 1e-10);
-    assertEquals(ByteBuffer.wrap(floatMinBytesMinMax).order(java.nio.ByteOrder.LITTLE_ENDIAN).getFloat(), Float.MIN_VALUE, 1e-10);
+    assertEquals(
+        ByteBuffer.wrap(floatMaxBytesMinMax)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getFloat(),
+        Float.MAX_VALUE,
+        1e-10);
+    assertEquals(
+        ByteBuffer.wrap(floatMinBytesMinMax)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getFloat(),
+        Float.MIN_VALUE,
+        1e-10);
 
-    FloatStatistics statsFromBytesMinMax= new FloatStatistics();
+    FloatStatistics statsFromBytesMinMax = new FloatStatistics();
     statsFromBytesMinMax.setMinMaxFromBytes(floatMinBytesMinMax, floatMaxBytesMinMax);
 
     assertEquals(statsFromBytesMinMax.getMax(), Float.MAX_VALUE, 1e-10);
@@ -279,7 +333,7 @@ public class TestStatistics {
     doubleArray = new double[] {81.5d, 944.5f, 2.002d, 334.5d, 5.6d, 0.001d, 0.00001d, 23.0d, 553.6d};
     DoubleStatistics stats = new DoubleStatistics();
 
-    for (double d: doubleArray) {
+    for (double d : doubleArray) {
       stats.updateStats(d);
     }
     assertEquals(stats.getMax(), 944.5d, 1e-10);
@@ -289,7 +343,7 @@ public class TestStatistics {
     doubleArray = new double[] {-81.5d, -944.5d, 2.002d, -334.5d, -5.6d, -0.001d, -0.00001d, 23.0d, -3.6d};
     DoubleStatistics statsNeg = new DoubleStatistics();
 
-    for (double d: doubleArray) {
+    for (double d : doubleArray) {
       statsNeg.updateStats(d);
     }
     assertEquals(statsNeg.getMax(), 23.0d, 1e-10);
@@ -306,8 +360,18 @@ public class TestStatistics {
     byte[] doubleMaxBytes = statsNeg.getMaxBytes();
     byte[] doubleMinBytes = statsNeg.getMinBytes();
 
-    assertEquals(ByteBuffer.wrap(doubleMaxBytes).order(java.nio.ByteOrder.LITTLE_ENDIAN).getDouble(), 23.0d, 1e-10);
-    assertEquals(ByteBuffer.wrap(doubleMinBytes).order(java.nio.ByteOrder.LITTLE_ENDIAN).getDouble(), -944.5d, 1e-10);
+    assertEquals(
+        ByteBuffer.wrap(doubleMaxBytes)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getDouble(),
+        23.0d,
+        1e-10);
+    assertEquals(
+        ByteBuffer.wrap(doubleMinBytes)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getDouble(),
+        -944.5d,
+        1e-10);
 
     DoubleStatistics statsFromBytes = new DoubleStatistics();
     statsFromBytes.setMinMaxFromBytes(doubleMinBytes, doubleMaxBytes);
@@ -318,7 +382,7 @@ public class TestStatistics {
     doubleArray = new double[] {Double.MAX_VALUE, Double.MIN_VALUE};
     DoubleStatistics minMaxValues = new DoubleStatistics();
 
-    for (double d: doubleArray) {
+    for (double d : doubleArray) {
       minMaxValues.updateStats(d);
     }
     assertEquals(minMaxValues.getMax(), Double.MAX_VALUE, 1e-10);
@@ -328,10 +392,20 @@ public class TestStatistics {
     byte[] doubleMaxBytesMinMax = minMaxValues.getMaxBytes();
     byte[] doubleMinBytesMinMax = minMaxValues.getMinBytes();
 
-    assertEquals(ByteBuffer.wrap(doubleMaxBytesMinMax).order(java.nio.ByteOrder.LITTLE_ENDIAN).getDouble(), Double.MAX_VALUE, 1e-10);
-    assertEquals(ByteBuffer.wrap(doubleMinBytesMinMax).order(java.nio.ByteOrder.LITTLE_ENDIAN).getDouble(), Double.MIN_VALUE, 1e-10);
+    assertEquals(
+        ByteBuffer.wrap(doubleMaxBytesMinMax)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getDouble(),
+        Double.MAX_VALUE,
+        1e-10);
+    assertEquals(
+        ByteBuffer.wrap(doubleMinBytesMinMax)
+            .order(java.nio.ByteOrder.LITTLE_ENDIAN)
+            .getDouble(),
+        Double.MIN_VALUE,
+        1e-10);
 
-    DoubleStatistics statsFromBytesMinMax= new DoubleStatistics();
+    DoubleStatistics statsFromBytesMinMax = new DoubleStatistics();
     statsFromBytesMinMax.setMinMaxFromBytes(doubleMinBytesMinMax, doubleMaxBytesMinMax);
 
     assertEquals(statsFromBytesMinMax.getMax(), Double.MAX_VALUE, 1e-10);
@@ -343,9 +417,11 @@ public class TestStatistics {
 
   @Test
   public void testFloatingPointStringIndependentFromLocale() {
-    Statistics<?> floatStats = Statistics.createStats(Types.optional(PrimitiveTypeName.FLOAT).named("test-float"));
+    Statistics<?> floatStats =
+        Statistics.createStats(Types.optional(PrimitiveTypeName.FLOAT).named("test-float"));
     floatStats.updateStats(123.456f);
-    Statistics<?> doubleStats = Statistics.createStats(Types.optional(PrimitiveTypeName.DOUBLE).named("test-double"));
+    Statistics<?> doubleStats =
+        Statistics.createStats(Types.optional(PrimitiveTypeName.DOUBLE).named("test-double"));
     doubleStats.updateStats(12345.6789);
 
     Locale defaultLocale = Locale.getDefault();
@@ -365,7 +441,7 @@ public class TestStatistics {
     booleanArray = new boolean[] {true, true, true};
     BooleanStatistics statsTrue = new BooleanStatistics();
 
-    for (boolean i: booleanArray) {
+    for (boolean i : booleanArray) {
       statsTrue.updateStats(i);
     }
     assertTrue(statsTrue.getMax());
@@ -375,7 +451,7 @@ public class TestStatistics {
     booleanArray = new boolean[] {false, false, false};
     BooleanStatistics statsFalse = new BooleanStatistics();
 
-    for (boolean i: booleanArray) {
+    for (boolean i : booleanArray) {
       statsFalse.updateStats(i);
     }
     assertFalse(statsFalse.getMax());
@@ -384,7 +460,7 @@ public class TestStatistics {
     booleanArray = new boolean[] {false, true, false};
     BooleanStatistics statsBoth = new BooleanStatistics();
 
-    for (boolean i: booleanArray) {
+    for (boolean i : booleanArray) {
       statsBoth.updateStats(i);
     }
     assertTrue(statsBoth.getMax());
@@ -409,12 +485,13 @@ public class TestStatistics {
 
   @Test
   public void testBinaryMinMax() {
-    //Test basic max/min
+    // Test basic max/min
     stringArray = new String[] {"hello", "world", "this", "is", "a", "test", "of", "the", "stats", "class"};
-    PrimitiveType type = Types.optional(PrimitiveTypeName.BINARY).as(OriginalType.UTF8).named("test_binary_utf8");
+    PrimitiveType type =
+        Types.optional(PrimitiveTypeName.BINARY).as(OriginalType.UTF8).named("test_binary_utf8");
     BinaryStatistics stats = (BinaryStatistics) Statistics.createStats(type);
 
-    for (String s: stringArray) {
+    for (String s : stringArray) {
       stats.updateStats(Binary.fromString(s));
     }
     assertEquals(stats.genericGetMax(), Binary.fromString("world"));
@@ -424,7 +501,7 @@ public class TestStatistics {
     stringArray = new String[] {"", "", "", "", ""};
     BinaryStatistics statsEmpty = (BinaryStatistics) Statistics.createStats(type);
 
-    for (String s: stringArray) {
+    for (String s : stringArray) {
       statsEmpty.updateStats(Binary.fromString(s));
     }
     assertEquals(statsEmpty.genericGetMax(), Binary.fromString(""));
@@ -451,7 +528,7 @@ public class TestStatistics {
   public void testBinaryMinMaxForReusedBackingByteArray() {
     BinaryStatistics stats = new BinaryStatistics();
 
-    byte[] bytes = new byte[] { 10 };
+    byte[] bytes = new byte[] {10};
     final Binary value = Binary.fromReusedByteArray(bytes);
     stats.updateStats(value);
 
@@ -461,8 +538,8 @@ public class TestStatistics {
     bytes[0] = 15;
     stats.updateStats(value);
 
-    assertArrayEquals(new byte[] { 20 }, stats.getMaxBytes());
-    assertArrayEquals(new byte[] { 10 }, stats.getMinBytes());
+    assertArrayEquals(new byte[] {20}, stats.getMaxBytes());
+    assertArrayEquals(new byte[] {10}, stats.getMinBytes());
   }
 
   @Test
@@ -479,14 +556,14 @@ public class TestStatistics {
     integerArray = new int[] {1, 2, 3, 4, 5};
     IntStatistics intStats = new IntStatistics();
 
-    for (int s: integerArray) {
+    for (int s : integerArray) {
       intStats.updateStats(s);
     }
 
     integerArray = new int[] {0, 3, 3};
     IntStatistics intStats2 = new IntStatistics();
 
-    for (int s: integerArray) {
+    for (int s : integerArray) {
       intStats2.updateStats(s);
     }
     intStats.mergeStatistics(intStats2);
@@ -495,7 +572,7 @@ public class TestStatistics {
 
     integerArray = new int[] {-1, -100, 100};
     IntStatistics intStats3 = new IntStatistics();
-    for (int s: integerArray) {
+    for (int s : integerArray) {
       intStats3.updateStats(s);
     }
     intStats.mergeStatistics(intStats3);
@@ -508,14 +585,14 @@ public class TestStatistics {
     longArray = new long[] {1l, 2l, 3l, 4l, 5l};
     LongStatistics longStats = new LongStatistics();
 
-    for (long s: longArray) {
+    for (long s : longArray) {
       longStats.updateStats(s);
     }
 
     longArray = new long[] {0l, 3l, 3l};
     LongStatistics longStats2 = new LongStatistics();
 
-    for (long s: longArray) {
+    for (long s : longArray) {
       longStats2.updateStats(s);
     }
     longStats.mergeStatistics(longStats2);
@@ -524,7 +601,7 @@ public class TestStatistics {
 
     longArray = new long[] {-1l, -100l, 100l};
     LongStatistics longStats3 = new LongStatistics();
-    for (long s: longArray) {
+    for (long s : longArray) {
       longStats3.updateStats(s);
     }
     longStats.mergeStatistics(longStats3);
@@ -537,14 +614,14 @@ public class TestStatistics {
     floatArray = new float[] {1.44f, 12.2f, 98.3f, 1.4f, 0.05f};
     FloatStatistics floatStats = new FloatStatistics();
 
-    for (float s: floatArray) {
+    for (float s : floatArray) {
       floatStats.updateStats(s);
     }
 
     floatArray = new float[] {0.0001f, 9.9f, 3.1f};
     FloatStatistics floatStats2 = new FloatStatistics();
 
-    for (float s: floatArray) {
+    for (float s : floatArray) {
       floatStats2.updateStats(s);
     }
     floatStats.mergeStatistics(floatStats2);
@@ -553,7 +630,7 @@ public class TestStatistics {
 
     floatArray = new float[] {-1.91f, -100.9f, 100.54f};
     FloatStatistics floatStats3 = new FloatStatistics();
-    for (float s: floatArray) {
+    for (float s : floatArray) {
       floatStats3.updateStats(s);
     }
     floatStats.mergeStatistics(floatStats3);
@@ -566,14 +643,14 @@ public class TestStatistics {
     doubleArray = new double[] {1.44d, 12.2d, 98.3d, 1.4d, 0.05d};
     DoubleStatistics doubleStats = new DoubleStatistics();
 
-    for (double s: doubleArray) {
+    for (double s : doubleArray) {
       doubleStats.updateStats(s);
     }
 
     doubleArray = new double[] {0.0001d, 9.9d, 3.1d};
     DoubleStatistics doubleStats2 = new DoubleStatistics();
 
-    for (double s: doubleArray) {
+    for (double s : doubleArray) {
       doubleStats2.updateStats(s);
     }
     doubleStats.mergeStatistics(doubleStats2);
@@ -582,7 +659,7 @@ public class TestStatistics {
 
     doubleArray = new double[] {-1.91d, -100.9d, 100.54d};
     DoubleStatistics doubleStats3 = new DoubleStatistics();
-    for (double s: doubleArray) {
+    for (double s : doubleArray) {
       doubleStats3.updateStats(s);
     }
     doubleStats.mergeStatistics(doubleStats3);
@@ -595,14 +672,14 @@ public class TestStatistics {
     booleanArray = new boolean[] {true, true, true};
     BooleanStatistics booleanStats = new BooleanStatistics();
 
-    for (boolean s: booleanArray) {
+    for (boolean s : booleanArray) {
       booleanStats.updateStats(s);
     }
 
     booleanArray = new boolean[] {true, false};
     BooleanStatistics booleanStats2 = new BooleanStatistics();
 
-    for (boolean s: booleanArray) {
+    for (boolean s : booleanArray) {
       booleanStats2.updateStats(s);
     }
     booleanStats.mergeStatistics(booleanStats2);
@@ -611,7 +688,7 @@ public class TestStatistics {
 
     booleanArray = new boolean[] {false, false, false, false};
     BooleanStatistics booleanStats3 = new BooleanStatistics();
-    for (boolean s: booleanArray) {
+    for (boolean s : booleanArray) {
       booleanStats3.updateStats(s);
     }
     booleanStats.mergeStatistics(booleanStats3);
@@ -624,14 +701,14 @@ public class TestStatistics {
     stringArray = new String[] {"hello", "world", "this", "is", "a", "test", "of", "the", "stats", "class"};
     BinaryStatistics stats = new BinaryStatistics();
 
-    for (String s: stringArray) {
+    for (String s : stringArray) {
       stats.updateStats(Binary.fromString(s));
     }
 
     stringArray = new String[] {"zzzz", "asdf", "testing"};
     BinaryStatistics stats2 = new BinaryStatistics();
 
-    for (String s: stringArray) {
+    for (String s : stringArray) {
       stats2.updateStats(Binary.fromString(s));
     }
     stats.mergeStatistics(stats2);
@@ -640,7 +717,7 @@ public class TestStatistics {
 
     stringArray = new String[] {"", "good", "testing"};
     BinaryStatistics stats3 = new BinaryStatistics();
-    for (String s: stringArray) {
+    for (String s : stringArray) {
       stats3.updateStats(Binary.fromString(s));
     }
     stats.mergeStatistics(stats3);
@@ -651,23 +728,42 @@ public class TestStatistics {
 
   @Test
   public void testBuilder() {
-    testBuilder(Types.required(BOOLEAN).named("test_boolean"), false, new byte[] { 0 }, true, new byte[] { 1 });
+    testBuilder(Types.required(BOOLEAN).named("test_boolean"), false, new byte[] {0}, true, new byte[] {1});
     testBuilder(Types.required(INT32).named("test_int32"), -42, intToBytes(-42), 42, intToBytes(42));
     testBuilder(Types.required(INT64).named("test_int64"), -42l, longToBytes(-42), 42l, longToBytes(42));
-    testBuilder(Types.required(FLOAT).named("test_float"), -42.0f, intToBytes(floatToIntBits(-42.0f)), 42.0f,
+    testBuilder(
+        Types.required(FLOAT).named("test_float"),
+        -42.0f,
+        intToBytes(floatToIntBits(-42.0f)),
+        42.0f,
         intToBytes(floatToIntBits(42.0f)));
-    testBuilder(Types.required(DOUBLE).named("test_double"), -42.0, longToBytes(doubleToLongBits(-42.0)), 42.0,
+    testBuilder(
+        Types.required(DOUBLE).named("test_double"),
+        -42.0,
+        longToBytes(doubleToLongBits(-42.0)),
+        42.0,
         longToBytes(Double.doubleToLongBits(42.0f)));
 
-    byte[] min = { 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 };
-    byte[] max = { 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24 };
-    testBuilder(Types.required(INT96).named("test_int96"), Binary.fromConstantByteArray(min), min,
-        Binary.fromConstantByteArray(max), max);
-    testBuilder(Types.required(FIXED_LEN_BYTE_ARRAY).length(12).named("test_fixed"), Binary.fromConstantByteArray(min),
+    byte[] min = {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12};
+    byte[] max = {13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24};
+    testBuilder(
+        Types.required(INT96).named("test_int96"),
+        Binary.fromConstantByteArray(min),
         min,
-        Binary.fromConstantByteArray(max), max);
-    testBuilder(Types.required(BINARY).named("test_binary"), Binary.fromConstantByteArray(min), min,
-        Binary.fromConstantByteArray(max), max);
+        Binary.fromConstantByteArray(max),
+        max);
+    testBuilder(
+        Types.required(FIXED_LEN_BYTE_ARRAY).length(12).named("test_fixed"),
+        Binary.fromConstantByteArray(min),
+        min,
+        Binary.fromConstantByteArray(max),
+        max);
+    testBuilder(
+        Types.required(BINARY).named("test_binary"),
+        Binary.fromConstantByteArray(min),
+        min,
+        Binary.fromConstantByteArray(max),
+        max);
   }
 
   private void testBuilder(PrimitiveType type, Object min, byte[] minBytes, Object max, byte[] maxBytes) {
@@ -706,40 +802,49 @@ public class TestStatistics {
     PrimitiveType type = Types.required(FLOAT).named("test_float");
     Statistics.Builder builder = Statistics.getBuilderForReading(type);
     Statistics<?> stats = builder.withMin(intToBytes(floatToIntBits(Float.NaN)))
-        .withMax(intToBytes(floatToIntBits(42.0f))).withNumNulls(0).build();
+        .withMax(intToBytes(floatToIntBits(42.0f)))
+        .withNumNulls(0)
+        .build();
     assertTrue(stats.isNumNullsSet());
     assertEquals(0, stats.getNumNulls());
     assertFalse(stats.hasNonNullValue());
 
     builder = Statistics.getBuilderForReading(type);
     stats = builder.withMin(intToBytes(floatToIntBits(-42.0f)))
-        .withMax(intToBytes(floatToIntBits(Float.NaN))).withNumNulls(11).build();
+        .withMax(intToBytes(floatToIntBits(Float.NaN)))
+        .withNumNulls(11)
+        .build();
     assertTrue(stats.isNumNullsSet());
     assertEquals(11, stats.getNumNulls());
     assertFalse(stats.hasNonNullValue());
 
     builder = Statistics.getBuilderForReading(type);
     stats = builder.withMin(intToBytes(floatToIntBits(Float.NaN)))
-        .withMax(intToBytes(floatToIntBits(Float.NaN))).withNumNulls(42).build();
+        .withMax(intToBytes(floatToIntBits(Float.NaN)))
+        .withNumNulls(42)
+        .build();
     assertTrue(stats.isNumNullsSet());
     assertEquals(42, stats.getNumNulls());
     assertFalse(stats.hasNonNullValue());
 
     builder = Statistics.getBuilderForReading(type);
     stats = builder.withMin(intToBytes(floatToIntBits(0.0f)))
-        .withMax(intToBytes(floatToIntBits(42.0f))).build();
+        .withMax(intToBytes(floatToIntBits(42.0f)))
+        .build();
     assertEquals(0, Float.compare(-0.0f, (Float) stats.genericGetMin()));
     assertEquals(0, Float.compare(42.0f, (Float) stats.genericGetMax()));
 
     builder = Statistics.getBuilderForReading(type);
     stats = builder.withMin(intToBytes(floatToIntBits(-42.0f)))
-        .withMax(intToBytes(floatToIntBits(-0.0f))).build();
+        .withMax(intToBytes(floatToIntBits(-0.0f)))
+        .build();
     assertEquals(0, Float.compare(-42.0f, (Float) stats.genericGetMin()));
     assertEquals(0, Float.compare(0.0f, (Float) stats.genericGetMax()));
 
     builder = Statistics.getBuilderForReading(type);
     stats = builder.withMin(intToBytes(floatToIntBits(0.0f)))
-        .withMax(intToBytes(floatToIntBits(-0.0f))).build();
+        .withMax(intToBytes(floatToIntBits(-0.0f)))
+        .build();
     assertEquals(0, Float.compare(-0.0f, (Float) stats.genericGetMin()));
     assertEquals(0, Float.compare(0.0f, (Float) stats.genericGetMax()));
   }
@@ -749,40 +854,49 @@ public class TestStatistics {
     PrimitiveType type = Types.required(DOUBLE).named("test_double");
     Statistics.Builder builder = Statistics.getBuilderForReading(type);
     Statistics<?> stats = builder.withMin(longToBytes(doubleToLongBits(Double.NaN)))
-        .withMax(longToBytes(doubleToLongBits(42.0))).withNumNulls(0).build();
+        .withMax(longToBytes(doubleToLongBits(42.0)))
+        .withNumNulls(0)
+        .build();
     assertTrue(stats.isNumNullsSet());
     assertEquals(0, stats.getNumNulls());
     assertFalse(stats.hasNonNullValue());
 
     builder = Statistics.getBuilderForReading(type);
     stats = builder.withMin(longToBytes(doubleToLongBits(-42.0)))
-        .withMax(longToBytes(doubleToLongBits(Double.NaN))).withNumNulls(11).build();
+        .withMax(longToBytes(doubleToLongBits(Double.NaN)))
+        .withNumNulls(11)
+        .build();
     assertTrue(stats.isNumNullsSet());
     assertEquals(11, stats.getNumNulls());
     assertFalse(stats.hasNonNullValue());
 
     builder = Statistics.getBuilderForReading(type);
     stats = builder.withMin(longToBytes(doubleToLongBits(Double.NaN)))
-        .withMax(longToBytes(doubleToLongBits(Double.NaN))).withNumNulls(42).build();
+        .withMax(longToBytes(doubleToLongBits(Double.NaN)))
+        .withNumNulls(42)
+        .build();
     assertTrue(stats.isNumNullsSet());
     assertEquals(42, stats.getNumNulls());
     assertFalse(stats.hasNonNullValue());
 
     builder = Statistics.getBuilderForReading(type);
     stats = builder.withMin(longToBytes(doubleToLongBits(0.0)))
-        .withMax(longToBytes(doubleToLongBits(42.0))).build();
+        .withMax(longToBytes(doubleToLongBits(42.0)))
+        .build();
     assertEquals(0, Double.compare(-0.0, (Double) stats.genericGetMin()));
     assertEquals(0, Double.compare(42.0, (Double) stats.genericGetMax()));
 
     builder = Statistics.getBuilderForReading(type);
     stats = builder.withMin(longToBytes(doubleToLongBits(-42.0)))
-        .withMax(longToBytes(doubleToLongBits(-0.0))).build();
+        .withMax(longToBytes(doubleToLongBits(-0.0)))
+        .build();
     assertEquals(0, Double.compare(-42.0, (Double) stats.genericGetMin()));
     assertEquals(0, Double.compare(0.0, (Double) stats.genericGetMax()));
 
     builder = Statistics.getBuilderForReading(type);
     stats = builder.withMin(longToBytes(doubleToLongBits(0.0)))
-        .withMax(longToBytes(doubleToLongBits(-0.0))).build();
+        .withMax(longToBytes(doubleToLongBits(-0.0)))
+        .build();
     assertEquals(0, Double.compare(-0.0, (Double) stats.genericGetMin()));
     assertEquals(0, Double.compare(0.0, (Double) stats.genericGetMax()));
   }
