@@ -19,9 +19,6 @@
 
 package org.apache.parquet.bytes;
 
-import org.junit.Assert;
-import org.junit.Test;
-
 import static org.junit.Assert.assertEquals;
 
 import java.io.EOFException;
@@ -31,11 +28,14 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 import java.util.concurrent.Callable;
+import org.junit.Assert;
+import org.junit.Test;
 
 public abstract class TestByteBufferInputStreams {
   static final int DATA_LENGTH = 35;
 
   protected abstract ByteBufferInputStream newStream();
+
   protected abstract void checkOriginalData();
 
   @Test
@@ -49,8 +49,7 @@ public abstract class TestByteBufferInputStreams {
     int bytesRead = stream.read(new byte[100]);
     Assert.assertTrue("Should read to end of stream", bytesRead < 100);
 
-    Assert.assertEquals("Should read 0 bytes at end of stream",
-        0, stream.read(bytes));
+    Assert.assertEquals("Should read 0 bytes at end of stream", 0, stream.read(bytes));
   }
 
   @Test
@@ -60,22 +59,18 @@ public abstract class TestByteBufferInputStreams {
     ByteBufferInputStream stream = newStream();
 
     int bytesRead = stream.read(bytes);
-    Assert.assertEquals("Should read the entire buffer",
-        bytes.length, bytesRead);
+    Assert.assertEquals("Should read the entire buffer", bytes.length, bytesRead);
 
     for (int i = 0; i < bytes.length; i += 1) {
       Assert.assertEquals("Byte i should be i", i, bytes[i]);
       Assert.assertEquals("Should advance position", 35, stream.position());
     }
 
-    Assert.assertEquals("Should have no more remaining content",
-        0, stream.available());
+    Assert.assertEquals("Should have no more remaining content", 0, stream.available());
 
-    Assert.assertEquals("Should return -1 at end of stream",
-        -1, stream.read(bytes));
+    Assert.assertEquals("Should return -1 at end of stream", -1, stream.read(bytes));
 
-    Assert.assertEquals("Should have no more remaining content",
-        0, stream.available());
+    Assert.assertEquals("Should have no more remaining content", 0, stream.available());
 
     checkOriginalData();
   }
@@ -90,13 +85,11 @@ public abstract class TestByteBufferInputStreams {
 
       int lastBytesRead = bytes.length;
       for (int offset = 0; offset < length; offset += bytes.length) {
-        Assert.assertEquals("Should read requested len",
-            bytes.length, lastBytesRead);
+        Assert.assertEquals("Should read requested len", bytes.length, lastBytesRead);
 
         lastBytesRead = stream.read(bytes, 0, bytes.length);
 
-        Assert.assertEquals("Should advance position",
-            offset + lastBytesRead, stream.position());
+        Assert.assertEquals("Should advance position", offset + lastBytesRead, stream.position());
 
         // validate the bytes that were read
         for (int i = 0; i < lastBytesRead; i += 1) {
@@ -104,17 +97,14 @@ public abstract class TestByteBufferInputStreams {
         }
       }
 
-      Assert.assertEquals("Should read fewer bytes at end of buffer",
-          length % bytes.length, lastBytesRead % bytes.length);
+      Assert.assertEquals(
+          "Should read fewer bytes at end of buffer", length % bytes.length, lastBytesRead % bytes.length);
 
-      Assert.assertEquals("Should have no more remaining content",
-          0, stream.available());
+      Assert.assertEquals("Should have no more remaining content", 0, stream.available());
 
-      Assert.assertEquals("Should return -1 at end of stream",
-          -1, stream.read(bytes));
+      Assert.assertEquals("Should return -1 at end of stream", -1, stream.read(bytes));
 
-      Assert.assertEquals("Should have no more remaining content",
-          0, stream.available());
+      Assert.assertEquals("Should have no more remaining content", 0, stream.available());
     }
 
     checkOriginalData();
@@ -131,35 +121,29 @@ public abstract class TestByteBufferInputStreams {
       for (int offset = 0; offset < bytes.length; offset += size) {
         Assert.assertEquals("Should read requested len", size, lastBytesRead);
 
-        lastBytesRead = stream.read(
-            bytes, offset, Math.min(size, bytes.length - offset));
+        lastBytesRead = stream.read(bytes, offset, Math.min(size, bytes.length - offset));
 
-        Assert.assertEquals("Should advance position",
+        Assert.assertEquals(
+            "Should advance position",
             lastBytesRead > 0 ? offset + lastBytesRead : offset,
             stream.position());
       }
 
-      Assert.assertEquals("Should read fewer bytes at end of buffer",
-          bytes.length % size, lastBytesRead % size);
+      Assert.assertEquals("Should read fewer bytes at end of buffer", bytes.length % size, lastBytesRead % size);
 
       for (int i = 0; i < bytes.length; i += 1) {
         Assert.assertEquals("Byte i should be i", i, bytes[i]);
       }
 
-      Assert.assertEquals("Should have no more remaining content",
-          2, stream.available());
+      Assert.assertEquals("Should have no more remaining content", 2, stream.available());
 
-      Assert.assertEquals("Should return 2 more bytes",
-          2, stream.read(bytes));
+      Assert.assertEquals("Should return 2 more bytes", 2, stream.read(bytes));
 
-      Assert.assertEquals("Should have no more remaining content",
-          0, stream.available());
+      Assert.assertEquals("Should have no more remaining content", 0, stream.available());
 
-      Assert.assertEquals("Should return -1 at end of stream",
-          -1, stream.read(bytes));
+      Assert.assertEquals("Should return -1 at end of stream", -1, stream.read(bytes));
 
-      Assert.assertEquals("Should have no more remaining content",
-          0, stream.available());
+      Assert.assertEquals("Should have no more remaining content", 0, stream.available());
     }
 
     checkOriginalData();
@@ -175,8 +159,8 @@ public abstract class TestByteBufferInputStreams {
       Assert.assertEquals(i, stream.read());
     }
 
-    assertThrows("Should throw EOFException at end of stream",
-        EOFException.class, (Callable<Integer>) stream::read);
+    assertThrows(
+        "Should throw EOFException at end of stream", EOFException.class, (Callable<Integer>) stream::read);
 
     checkOriginalData();
   }
@@ -188,8 +172,7 @@ public abstract class TestByteBufferInputStreams {
 
     ByteBuffer empty = stream.slice(0);
     Assert.assertNotNull("slice(0) should produce a non-null buffer", empty);
-    Assert.assertEquals("slice(0) should produce an empty buffer",
-        0, empty.remaining());
+    Assert.assertEquals("slice(0) should produce an empty buffer", 0, empty.remaining());
 
     Assert.assertEquals("Position should be at start", 0, stream.position());
 
@@ -214,8 +197,7 @@ public abstract class TestByteBufferInputStreams {
   public void testSliceBuffers0() throws Exception {
     ByteBufferInputStream stream = newStream();
 
-    Assert.assertEquals("Should return an empty list",
-        Collections.emptyList(), stream.sliceBuffers(0));
+    Assert.assertEquals("Should return an empty list", Collections.emptyList(), stream.sliceBuffers(0));
   }
 
   @Test
@@ -227,8 +209,8 @@ public abstract class TestByteBufferInputStreams {
 
     Assert.assertEquals("Should consume all buffers", length, stream.position());
 
-    assertThrows("Should throw EOFException when empty",
-        EOFException.class, (Callable<List<ByteBuffer>>) () -> stream.sliceBuffers(length));
+    assertThrows("Should throw EOFException when empty", EOFException.class, (Callable<List<ByteBuffer>>)
+        () -> stream.sliceBuffers(length));
 
     ByteBufferInputStream copy = ByteBufferInputStream.wrap(buffers);
     for (int i = 0; i < length; i += 1) {
@@ -249,8 +231,7 @@ public abstract class TestByteBufferInputStreams {
         buffers.addAll(stream.sliceBuffers(Math.min(size, stream.available())));
       }
 
-      Assert.assertEquals("Should consume all content",
-          length, stream.position());
+      Assert.assertEquals("Should consume all content", length, stream.position());
 
       ByteBufferInputStream newStream = new MultiBufferInputStream(buffers);
 
@@ -269,17 +250,13 @@ public abstract class TestByteBufferInputStreams {
 
     int sliceLength = 5;
     List<ByteBuffer> buffers = stream.sliceBuffers(sliceLength);
-    Assert.assertEquals("Should advance the original stream",
-        length - sliceLength, stream.available());
-    Assert.assertEquals("Should advance the original stream position",
-        sliceLength, stream.position());
+    Assert.assertEquals("Should advance the original stream", length - sliceLength, stream.available());
+    Assert.assertEquals("Should advance the original stream position", sliceLength, stream.position());
 
-    Assert.assertEquals("Should return a slice of the first buffer",
-        1, buffers.size());
+    Assert.assertEquals("Should return a slice of the first buffer", 1, buffers.size());
 
     ByteBuffer buffer = buffers.get(0);
-    Assert.assertEquals("Should have requested bytes",
-        sliceLength, buffer.remaining());
+    Assert.assertEquals("Should have requested bytes", sliceLength, buffer.remaining());
 
     // read the buffer one past the returned limit. this should not change the
     // next value in the original stream
@@ -288,10 +265,8 @@ public abstract class TestByteBufferInputStreams {
       Assert.assertEquals("Should have correct data", i, buffer.get());
     }
 
-    Assert.assertEquals("Reading a slice shouldn't advance the original stream",
-        sliceLength, stream.position());
-    Assert.assertEquals("Reading a slice shouldn't change the underlying data",
-        sliceLength, stream.read());
+    Assert.assertEquals("Reading a slice shouldn't advance the original stream", sliceLength, stream.position());
+    Assert.assertEquals("Reading a slice shouldn't change the underlying data", sliceLength, stream.read());
 
     // change the underlying data buffer
     buffer.limit(sliceLength + 2);
@@ -302,12 +277,8 @@ public abstract class TestByteBufferInputStreams {
       buffer.put((byte) 255);
 
       Assert.assertEquals(
-          "Writing to a slice shouldn't advance the original stream",
-          sliceLength + 1, stream.position());
-      Assert.assertEquals(
-          "Writing to a slice should change the underlying data",
-          255, stream.read());
-
+          "Writing to a slice shouldn't advance the original stream", sliceLength + 1, stream.position());
+      Assert.assertEquals("Writing to a slice should change the underlying data", 255, stream.read());
     } finally {
       undoBuffer.put((byte) originalValue);
     }
@@ -319,18 +290,16 @@ public abstract class TestByteBufferInputStreams {
 
     while (stream.available() > 0) {
       int bytesToSkip = Math.min(stream.available(), 10);
-      Assert.assertEquals("Should skip all, regardless of backing buffers",
-          bytesToSkip, stream.skip(bytesToSkip));
+      Assert.assertEquals(
+          "Should skip all, regardless of backing buffers", bytesToSkip, stream.skip(bytesToSkip));
     }
 
     stream = newStream();
     Assert.assertEquals(0, stream.skip(0));
 
     int length = stream.available();
-    Assert.assertEquals("Should stop at end when out of bytes",
-        length, stream.skip(length + 10));
-    Assert.assertEquals("Should return -1 when at end",
-        -1, stream.skip(10));
+    Assert.assertEquals("Should stop at end when out of bytes", length, stream.skip(length + 10));
+    Assert.assertEquals("Should return -1 when at end", -1, stream.skip(10));
   }
 
   @Test
@@ -343,8 +312,8 @@ public abstract class TestByteBufferInputStreams {
 
       stream.skipFully(bytesToSkip);
 
-      Assert.assertEquals("Should skip all, regardless of backing buffers",
-          bytesToSkip, stream.position() - lastPosition);
+      Assert.assertEquals(
+          "Should skip all, regardless of backing buffers", bytesToSkip, stream.position() - lastPosition);
 
       lastPosition = stream.position();
     }
@@ -354,11 +323,10 @@ public abstract class TestByteBufferInputStreams {
     Assert.assertEquals(0, stream2.position());
 
     final int length = stream2.available();
-    assertThrows("Should throw when out of bytes",
-        EOFException.class, () -> {
-          stream2.skipFully(length + 10);
-          return null;
-        });
+    assertThrows("Should throw when out of bytes", EOFException.class, () -> {
+      stream2.skipFully(length + 10);
+      return null;
+    });
   }
 
   @Test
@@ -377,17 +345,14 @@ public abstract class TestByteBufferInputStreams {
 
     stream.reset();
 
-    Assert.assertEquals("Position should return to the mark",
-        mark, stream.position());
+    Assert.assertEquals("Position should return to the mark", mark, stream.position());
 
     byte[] afterReset = new byte[100];
     int bytesReadAfterReset = stream.read(afterReset);
 
-    Assert.assertEquals("Should read the same number of bytes",
-        expectedBytesRead, bytesReadAfterReset);
+    Assert.assertEquals("Should read the same number of bytes", expectedBytesRead, bytesReadAfterReset);
 
-    Assert.assertEquals("Read should end at the same position",
-        end, stream.position());
+    Assert.assertEquals("Read should end at the same position", end, stream.position());
 
     Assert.assertArrayEquals("Content should be equal", expected, afterReset);
   }
@@ -409,17 +374,14 @@ public abstract class TestByteBufferInputStreams {
 
     stream.reset();
 
-    Assert.assertEquals("Position should return to the mark",
-        mark, stream.position());
+    Assert.assertEquals("Position should return to the mark", mark, stream.position());
 
     byte[] afterReset = new byte[100];
     int bytesReadAfterReset = stream.read(afterReset);
 
-    Assert.assertEquals("Should read the same number of bytes",
-        expectedBytesRead, bytesReadAfterReset);
+    Assert.assertEquals("Should read the same number of bytes", expectedBytesRead, bytesReadAfterReset);
 
-    Assert.assertEquals("Read should end at the same position",
-        end, stream.position());
+    Assert.assertEquals("Read should end at the same position", end, stream.position());
 
     Assert.assertArrayEquals("Content should be equal", expected, afterReset);
   }
@@ -439,14 +401,12 @@ public abstract class TestByteBufferInputStreams {
 
     stream.reset();
 
-    Assert.assertEquals("Position should return to the mark",
-        mark, stream.position());
+    Assert.assertEquals("Position should return to the mark", mark, stream.position());
 
     byte[] afterReset = new byte[10];
     Assert.assertEquals("Should read 10 bytes", 10, stream.read(afterReset));
 
-    Assert.assertEquals("Read should end at the same position",
-        end, stream.position());
+    Assert.assertEquals("Read should end at the same position", end, stream.position());
 
     Assert.assertArrayEquals("Content should be equal", expected, afterReset);
   }
@@ -469,14 +429,12 @@ public abstract class TestByteBufferInputStreams {
 
     stream.reset();
 
-    Assert.assertEquals("Position should return to the mark",
-        mark, stream.position());
+    Assert.assertEquals("Position should return to the mark", mark, stream.position());
 
     byte[] afterReset = new byte[10];
     Assert.assertEquals("Should read 0 bytes", -1, stream.read(afterReset));
 
-    Assert.assertEquals("Read should end at the same position",
-        end, stream.position());
+    Assert.assertEquals("Read should end at the same position", end, stream.position());
 
     Assert.assertArrayEquals("Content should be equal", expected, afterReset);
   }
@@ -485,11 +443,10 @@ public abstract class TestByteBufferInputStreams {
   public void testMarkUnset() {
     final ByteBufferInputStream stream = newStream();
 
-    assertThrows("Should throw an error for reset() without mark()",
-        IOException.class, () -> {
-          stream.reset();
-          return null;
-        });
+    assertThrows("Should throw an error for reset() without mark()", IOException.class, () -> {
+      stream.reset();
+      return null;
+    });
   }
 
   @Test
@@ -498,27 +455,22 @@ public abstract class TestByteBufferInputStreams {
 
     byte[] expected = new byte[6];
     stream.mark(10);
-    Assert.assertEquals("Should read expected bytes",
-        expected.length, stream.read(expected));
+    Assert.assertEquals("Should read expected bytes", expected.length, stream.read(expected));
 
     stream.reset();
     stream.mark(10);
 
     byte[] firstRead = new byte[6];
-    Assert.assertEquals("Should read firstRead bytes",
-        firstRead.length, stream.read(firstRead));
+    Assert.assertEquals("Should read firstRead bytes", firstRead.length, stream.read(firstRead));
 
     stream.reset();
 
     byte[] secondRead = new byte[6];
-    Assert.assertEquals("Should read secondRead bytes",
-        secondRead.length, stream.read(secondRead));
+    Assert.assertEquals("Should read secondRead bytes", secondRead.length, stream.read(secondRead));
 
-    Assert.assertArrayEquals("First read should be correct",
-        expected, firstRead);
+    Assert.assertArrayEquals("First read should be correct", expected, firstRead);
 
-    Assert.assertArrayEquals("Second read should be correct",
-        expected, secondRead);
+    Assert.assertArrayEquals("Second read should be correct", expected, secondRead);
   }
 
   @Test
@@ -532,11 +484,10 @@ public abstract class TestByteBufferInputStreams {
 
     Assert.assertEquals("Should read 6 bytes", 6, stream.read(new byte[6]));
 
-    assertThrows("Should throw an error for reset() after limit",
-        IOException.class, () -> {
-          stream.reset();
-          return null;
-        });
+    assertThrows("Should throw an error for reset() after limit", IOException.class, () -> {
+      stream.reset();
+      return null;
+    });
   }
 
   @Test
@@ -548,11 +499,10 @@ public abstract class TestByteBufferInputStreams {
 
     stream.reset();
 
-    assertThrows("Should throw an error for double reset()",
-        IOException.class, () -> {
-          stream.reset();
-          return null;
-        });
+    assertThrows("Should throw an error for double reset()", IOException.class, () -> {
+      stream.reset();
+      return null;
+    });
   }
 
   @Test
@@ -567,16 +517,15 @@ public abstract class TestByteBufferInputStreams {
 
   /**
    * A convenience method to avoid a large number of @Test(expected=...) tests
-   * @param message A String message to describe this assertion
+   *
+   * @param message  A String message to describe this assertion
    * @param expected An Exception class that the Runnable should throw
    * @param callable A Callable that is expected to throw the exception
    */
-  public static void assertThrows(
-      String message, Class<? extends Exception> expected, Callable callable) {
+  public static void assertThrows(String message, Class<? extends Exception> expected, Callable callable) {
     try {
       callable.call();
-      Assert.fail("No exception was thrown (" + message + "), expected: " +
-          expected.getName());
+      Assert.fail("No exception was thrown (" + message + "), expected: " + expected.getName());
     } catch (Exception actual) {
       try {
         Assert.assertEquals(message, expected, actual.getClass());
