@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,37 +18,8 @@
  */
 package org.apache.parquet.filter2.statisticslevel;
 
-import java.util.Arrays;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Set;
-
-import org.junit.Test;
-
-import org.apache.parquet.column.Encoding;
-import org.apache.parquet.column.statistics.DoubleStatistics;
-import org.apache.parquet.column.statistics.IntStatistics;
-import org.apache.parquet.hadoop.metadata.ColumnPath;
-import org.apache.parquet.filter2.predicate.FilterPredicate;
-import org.apache.parquet.filter2.predicate.LogicalInverseRewriter;
-import org.apache.parquet.filter2.predicate.Operators.BinaryColumn;
-import org.apache.parquet.filter2.predicate.Operators.DoubleColumn;
-import org.apache.parquet.filter2.predicate.Operators.IntColumn;
-import org.apache.parquet.filter2.predicate.Statistics;
-import org.apache.parquet.filter2.predicate.UserDefinedPredicate;
-import org.apache.parquet.hadoop.metadata.ColumnChunkMetaData;
-import org.apache.parquet.hadoop.metadata.CompressionCodecName;
-import org.apache.parquet.io.api.Binary;
-import org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName;
-import org.apache.parquet.schema.Types;
-
-import static org.apache.parquet.filter2.predicate.FilterApi.binaryColumn;
-import static org.apache.parquet.io.api.Binary.fromString;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
 import static org.apache.parquet.filter2.predicate.FilterApi.and;
+import static org.apache.parquet.filter2.predicate.FilterApi.binaryColumn;
 import static org.apache.parquet.filter2.predicate.FilterApi.doubleColumn;
 import static org.apache.parquet.filter2.predicate.FilterApi.eq;
 import static org.apache.parquet.filter2.predicate.FilterApi.gt;
@@ -63,27 +34,64 @@ import static org.apache.parquet.filter2.predicate.FilterApi.notIn;
 import static org.apache.parquet.filter2.predicate.FilterApi.or;
 import static org.apache.parquet.filter2.predicate.FilterApi.userDefined;
 import static org.apache.parquet.filter2.statisticslevel.StatisticsFilter.canDrop;
+import static org.apache.parquet.io.api.Binary.fromString;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
+import java.util.Arrays;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Set;
+import org.apache.parquet.column.Encoding;
+import org.apache.parquet.column.statistics.DoubleStatistics;
+import org.apache.parquet.column.statistics.IntStatistics;
+import org.apache.parquet.filter2.predicate.FilterPredicate;
+import org.apache.parquet.filter2.predicate.LogicalInverseRewriter;
+import org.apache.parquet.filter2.predicate.Operators.BinaryColumn;
+import org.apache.parquet.filter2.predicate.Operators.DoubleColumn;
+import org.apache.parquet.filter2.predicate.Operators.IntColumn;
+import org.apache.parquet.filter2.predicate.Statistics;
+import org.apache.parquet.filter2.predicate.UserDefinedPredicate;
+import org.apache.parquet.hadoop.metadata.ColumnChunkMetaData;
+import org.apache.parquet.hadoop.metadata.ColumnPath;
+import org.apache.parquet.hadoop.metadata.CompressionCodecName;
+import org.apache.parquet.io.api.Binary;
+import org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName;
+import org.apache.parquet.schema.Types;
+import org.junit.Test;
 
 public class TestStatisticsFilter {
 
-  private static ColumnChunkMetaData getIntColumnMeta(org.apache.parquet.column.statistics.Statistics<?> stats,
-      long valueCount) {
-    return ColumnChunkMetaData.get(ColumnPath.get("int", "column"),
+  private static ColumnChunkMetaData getIntColumnMeta(
+      org.apache.parquet.column.statistics.Statistics<?> stats, long valueCount) {
+    return ColumnChunkMetaData.get(
+        ColumnPath.get("int", "column"),
         PrimitiveTypeName.INT32,
         CompressionCodecName.GZIP,
         new HashSet<Encoding>(Arrays.asList(Encoding.PLAIN)),
         stats,
-        0L, 0L, valueCount, 0L, 0L);
+        0L,
+        0L,
+        valueCount,
+        0L,
+        0L);
   }
 
-  private static ColumnChunkMetaData getDoubleColumnMeta(org.apache.parquet.column.statistics.Statistics<?> stats,
-      long valueCount) {
-    return ColumnChunkMetaData.get(ColumnPath.get("double", "column"),
+  private static ColumnChunkMetaData getDoubleColumnMeta(
+      org.apache.parquet.column.statistics.Statistics<?> stats, long valueCount) {
+    return ColumnChunkMetaData.get(
+        ColumnPath.get("double", "column"),
         PrimitiveTypeName.DOUBLE,
         CompressionCodecName.GZIP,
         new HashSet<Encoding>(Arrays.asList(Encoding.PLAIN)),
         stats,
-        0L, 0L, valueCount, 0L, 0L);
+        0L,
+        0L,
+        valueCount,
+        0L,
+        0L);
   }
 
   private static final IntColumn intColumn = intColumn("int.column");
@@ -93,11 +101,16 @@ public class TestStatisticsFilter {
 
   private static final IntStatistics intStats = new IntStatistics();
   private static final IntStatistics nullIntStats = new IntStatistics();
-  private static final org.apache.parquet.column.statistics.Statistics<?> emptyIntStats = org.apache.parquet.column.statistics.Statistics
-      .getBuilderForReading(Types.required(PrimitiveTypeName.INT32).named("test_int32")).build();
+  private static final org.apache.parquet.column.statistics.Statistics<?> emptyIntStats =
+      org.apache.parquet.column.statistics.Statistics.getBuilderForReading(
+              Types.required(PrimitiveTypeName.INT32).named("test_int32"))
+          .build();
   private static final DoubleStatistics doubleStats = new DoubleStatistics();
-  private static final org.apache.parquet.column.statistics.Statistics<?> missingMinMaxDoubleStats = org.apache.parquet.column.statistics.Statistics
-      .getBuilderForReading(Types.required(PrimitiveTypeName.DOUBLE).named("test_double")).withNumNulls(100).build();
+  private static final org.apache.parquet.column.statistics.Statistics<?> missingMinMaxDoubleStats =
+      org.apache.parquet.column.statistics.Statistics.getBuilderForReading(
+              Types.required(PrimitiveTypeName.DOUBLE).named("test_double"))
+          .withNumNulls(100)
+          .build();
 
   static {
     intStats.setMinMax(10, 100);
@@ -106,16 +119,15 @@ public class TestStatisticsFilter {
     nullIntStats.setNumNulls(177);
   }
 
-  private static final List<ColumnChunkMetaData> columnMetas = Arrays.asList(
-      getIntColumnMeta(intStats, 177L),
-      getDoubleColumnMeta(doubleStats, 177L));
+  private static final List<ColumnChunkMetaData> columnMetas =
+      Arrays.asList(getIntColumnMeta(intStats, 177L), getDoubleColumnMeta(doubleStats, 177L));
 
   private static final List<ColumnChunkMetaData> nullColumnMetas = Arrays.asList(
       getIntColumnMeta(nullIntStats, 177L), // column of all nulls
       getDoubleColumnMeta(doubleStats, 177L));
 
   private static final List<ColumnChunkMetaData> missingMinMaxColumnMetas = Arrays.asList(
-      getIntColumnMeta(emptyIntStats, 177L),                // missing min/max values and numNulls => stats is empty
+      getIntColumnMeta(emptyIntStats, 177L), // missing min/max values and numNulls => stats is empty
       getDoubleColumnMeta(missingMinMaxDoubleStats, 177L)); // missing min/max, some null values
 
   @Test
@@ -143,13 +155,13 @@ public class TestStatisticsFilter {
     statsSomeNulls.setMinMax(10, 100);
     statsSomeNulls.setNumNulls(3);
 
-    assertTrue(canDrop(eq(intColumn, null), Arrays.asList(
-        getIntColumnMeta(statsNoNulls, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(canDrop(
+        eq(intColumn, null),
+        Arrays.asList(getIntColumnMeta(statsNoNulls, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(eq(intColumn, null), Arrays.asList(
-        getIntColumnMeta(statsSomeNulls, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        eq(intColumn, null),
+        Arrays.asList(getIntColumnMeta(statsSomeNulls, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
     assertFalse(canDrop(eq(missingColumn, null), columnMetas));
 
@@ -166,19 +178,19 @@ public class TestStatisticsFilter {
 
     IntStatistics allSevens = new IntStatistics();
     allSevens.setMinMax(7, 7);
-    assertTrue(canDrop(notEq(intColumn, 7), Arrays.asList(
-        getIntColumnMeta(allSevens, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(canDrop(
+        notEq(intColumn, 7),
+        Arrays.asList(getIntColumnMeta(allSevens, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
     allSevens.setNumNulls(100L);
-    assertFalse(canDrop(notEq(intColumn, 7), Arrays.asList(
-        getIntColumnMeta(allSevens, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        notEq(intColumn, 7),
+        Arrays.asList(getIntColumnMeta(allSevens, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
     allSevens.setNumNulls(177L);
-    assertFalse(canDrop(notEq(intColumn, 7), Arrays.asList(
-        getIntColumnMeta(allSevens, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        notEq(intColumn, 7),
+        Arrays.asList(getIntColumnMeta(allSevens, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
     assertFalse(canDrop(notEq(missingColumn, fromString("any")), columnMetas));
 
@@ -200,17 +212,17 @@ public class TestStatisticsFilter {
     statsAllNulls.setMinMax(0, 0);
     statsAllNulls.setNumNulls(177);
 
-    assertFalse(canDrop(notEq(intColumn, null), Arrays.asList(
-        getIntColumnMeta(statsNoNulls, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        notEq(intColumn, null),
+        Arrays.asList(getIntColumnMeta(statsNoNulls, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(notEq(intColumn, null), Arrays.asList(
-        getIntColumnMeta(statsSomeNulls, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        notEq(intColumn, null),
+        Arrays.asList(getIntColumnMeta(statsSomeNulls, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertTrue(canDrop(notEq(intColumn, null), Arrays.asList(
-        getIntColumnMeta(statsAllNulls, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(canDrop(
+        notEq(intColumn, null),
+        Arrays.asList(getIntColumnMeta(statsAllNulls, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
     assertTrue(canDrop(notEq(missingColumn, null), columnMetas));
 
@@ -352,21 +364,21 @@ public class TestStatisticsFilter {
 
     Set<Integer> values9 = new HashSet<>();
     values9.add(null);
-    assertTrue(canDrop(in(intColumn, values9), Arrays.asList(
-      getIntColumnMeta(statsNoNulls, 177L),
-      getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(canDrop(
+        in(intColumn, values9),
+        Arrays.asList(getIntColumnMeta(statsNoNulls, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(notIn(intColumn, values9), Arrays.asList(
-      getIntColumnMeta(statsNoNulls, 177L),
-      getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        notIn(intColumn, values9),
+        Arrays.asList(getIntColumnMeta(statsNoNulls, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(in(intColumn, values9), Arrays.asList(
-      getIntColumnMeta(statsSomeNulls, 177L),
-      getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        in(intColumn, values9),
+        Arrays.asList(getIntColumnMeta(statsSomeNulls, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(notIn(intColumn, values9), Arrays.asList(
-      getIntColumnMeta(statsSomeNulls, 177L),
-      getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        notIn(intColumn, values9),
+        Arrays.asList(getIntColumnMeta(statsSomeNulls, 177L), getDoubleColumnMeta(doubleStats, 177L))));
   }
 
   @Test
@@ -446,10 +458,12 @@ public class TestStatisticsFilter {
     FilterPredicate invPred = LogicalInverseRewriter.rewrite(not(userDefined(intColumn, SevensAndEightsUdp.class)));
 
     FilterPredicate udpDropMissingColumn = userDefined(missingColumn2, DropNullUdp.class);
-    FilterPredicate invUdpDropMissingColumn = LogicalInverseRewriter.rewrite(not(userDefined(missingColumn2, DropNullUdp.class)));
+    FilterPredicate invUdpDropMissingColumn =
+        LogicalInverseRewriter.rewrite(not(userDefined(missingColumn2, DropNullUdp.class)));
 
     FilterPredicate udpKeepMissingColumn = userDefined(missingColumn2, SevensAndEightsUdp.class);
-    FilterPredicate invUdpKeepMissingColumn = LogicalInverseRewriter.rewrite(not(userDefined(missingColumn2, SevensAndEightsUdp.class)));
+    FilterPredicate invUdpKeepMissingColumn =
+        LogicalInverseRewriter.rewrite(not(userDefined(missingColumn2, SevensAndEightsUdp.class)));
 
     FilterPredicate allPositivePred = userDefined(doubleColumn, AllPositiveUdp.class);
 
@@ -460,83 +474,76 @@ public class TestStatisticsFilter {
     eight.setMinMax(8, 8);
 
     IntStatistics neither = new IntStatistics();
-    neither.setMinMax(1 , 2);
+    neither.setMinMax(1, 2);
 
-    assertTrue(canDrop(pred, Arrays.asList(
-        getIntColumnMeta(seven, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(canDrop(pred, Arrays.asList(getIntColumnMeta(seven, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(pred, Arrays.asList(
-        getIntColumnMeta(eight, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(
+        canDrop(pred, Arrays.asList(getIntColumnMeta(eight, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(pred, Arrays.asList(
-        getIntColumnMeta(neither, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(
+        canDrop(pred, Arrays.asList(getIntColumnMeta(neither, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(invPred, Arrays.asList(
-        getIntColumnMeta(seven, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(
+        canDrop(invPred, Arrays.asList(getIntColumnMeta(seven, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertTrue(canDrop(invPred, Arrays.asList(
-        getIntColumnMeta(eight, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(
+        canDrop(invPred, Arrays.asList(getIntColumnMeta(eight, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(invPred, Arrays.asList(
-        getIntColumnMeta(neither, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        invPred, Arrays.asList(getIntColumnMeta(neither, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
     // udpDropMissingColumn drops null column.
-    assertTrue(canDrop(udpDropMissingColumn, Arrays.asList(
-        getIntColumnMeta(seven, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(canDrop(
+        udpDropMissingColumn,
+        Arrays.asList(getIntColumnMeta(seven, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertTrue(canDrop(udpDropMissingColumn, Arrays.asList(
-        getIntColumnMeta(eight, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(canDrop(
+        udpDropMissingColumn,
+        Arrays.asList(getIntColumnMeta(eight, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertTrue(canDrop(udpDropMissingColumn, Arrays.asList(
-        getIntColumnMeta(neither, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(canDrop(
+        udpDropMissingColumn,
+        Arrays.asList(getIntColumnMeta(neither, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
     // invUdpDropMissingColumn (i.e., not(udpDropMissingColumn)) keeps null column.
-    assertFalse(canDrop(invUdpDropMissingColumn, Arrays.asList(
-        getIntColumnMeta(seven, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        invUdpDropMissingColumn,
+        Arrays.asList(getIntColumnMeta(seven, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(invUdpDropMissingColumn, Arrays.asList(
-        getIntColumnMeta(eight, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        invUdpDropMissingColumn,
+        Arrays.asList(getIntColumnMeta(eight, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(invUdpDropMissingColumn, Arrays.asList(
-        getIntColumnMeta(neither, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        invUdpDropMissingColumn,
+        Arrays.asList(getIntColumnMeta(neither, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
     // udpKeepMissingColumn keeps null column.
-    assertFalse(canDrop(udpKeepMissingColumn, Arrays.asList(
-        getIntColumnMeta(seven, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        udpKeepMissingColumn,
+        Arrays.asList(getIntColumnMeta(seven, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(udpKeepMissingColumn, Arrays.asList(
-        getIntColumnMeta(eight, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        udpKeepMissingColumn,
+        Arrays.asList(getIntColumnMeta(eight, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertFalse(canDrop(udpKeepMissingColumn, Arrays.asList(
-        getIntColumnMeta(neither, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertFalse(canDrop(
+        udpKeepMissingColumn,
+        Arrays.asList(getIntColumnMeta(neither, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
     // invUdpKeepMissingColumn (i.e., not(udpKeepMissingColumn)) drops null column.
-    assertTrue(canDrop(invUdpKeepMissingColumn, Arrays.asList(
-        getIntColumnMeta(seven, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(canDrop(
+        invUdpKeepMissingColumn,
+        Arrays.asList(getIntColumnMeta(seven, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertTrue(canDrop(invUdpKeepMissingColumn, Arrays.asList(
-        getIntColumnMeta(eight, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(canDrop(
+        invUdpKeepMissingColumn,
+        Arrays.asList(getIntColumnMeta(eight, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
-    assertTrue(canDrop(invUdpKeepMissingColumn, Arrays.asList(
-        getIntColumnMeta(neither, 177L),
-        getDoubleColumnMeta(doubleStats, 177L))));
+    assertTrue(canDrop(
+        invUdpKeepMissingColumn,
+        Arrays.asList(getIntColumnMeta(neither, 177L), getDoubleColumnMeta(doubleStats, 177L))));
 
     assertFalse(canDrop(allPositivePred, missingMinMaxColumnMetas));
   }
@@ -544,8 +551,7 @@ public class TestStatisticsFilter {
   @Test
   public void testClearExceptionForNots() {
     List<ColumnChunkMetaData> columnMetas = Arrays.asList(
-        getDoubleColumnMeta(new DoubleStatistics(), 0L),
-        getIntColumnMeta(new IntStatistics(), 0L));
+        getDoubleColumnMeta(new DoubleStatistics(), 0L), getIntColumnMeta(new IntStatistics(), 0L));
 
     FilterPredicate pred = and(not(eq(doubleColumn, 12.0)), eq(intColumn, 17));
 
@@ -553,9 +559,10 @@ public class TestStatisticsFilter {
       canDrop(pred, columnMetas);
       fail("This should throw");
     } catch (IllegalArgumentException e) {
-      assertEquals("This predicate contains a not! Did you forget to run this predicate through LogicalInverseRewriter?"
-          + " not(eq(double.column, 12.0))", e.getMessage());
+      assertEquals(
+          "This predicate contains a not! Did you forget to run this predicate through LogicalInverseRewriter?"
+              + " not(eq(double.column, 12.0))",
+          e.getMessage());
     }
   }
-
 }
