@@ -19,11 +19,6 @@
 package org.apache.parquet.hadoop;
 
 import static java.util.Arrays.asList;
-import static org.apache.parquet.schema.LogicalTypeAnnotation.stringType;
-import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.BINARY;
-import static org.apache.parquet.schema.Type.Repetition.REQUIRED;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
 import static org.apache.parquet.column.Encoding.DELTA_BYTE_ARRAY;
 import static org.apache.parquet.column.Encoding.PLAIN;
 import static org.apache.parquet.column.Encoding.PLAIN_DICTIONARY;
@@ -34,8 +29,14 @@ import static org.apache.parquet.format.converter.ParquetMetadataConverter.NO_FI
 import static org.apache.parquet.hadoop.ParquetFileReader.readFooter;
 import static org.apache.parquet.hadoop.TestUtils.enforceEmptyDir;
 import static org.apache.parquet.hadoop.metadata.CompressionCodecName.UNCOMPRESSED;
+import static org.apache.parquet.schema.LogicalTypeAnnotation.stringType;
 import static org.apache.parquet.schema.MessageTypeParser.parseMessageType;
+import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.BINARY;
+import static org.apache.parquet.schema.Type.Repetition.REQUIRED;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 
+import com.google.common.collect.ImmutableMap;
 import java.io.File;
 import java.io.IOException;
 import java.util.HashMap;
@@ -43,38 +44,39 @@ import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.Callable;
-
 import net.openhft.hashing.LongHashFunction;
 import org.apache.commons.lang3.RandomStringUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
-import org.apache.parquet.column.ParquetProperties;
-import org.apache.parquet.column.values.bloomfilter.BlockSplitBloomFilter;
-import org.apache.parquet.column.values.bloomfilter.BloomFilter;
-import org.apache.parquet.example.data.GroupFactory;
-import org.apache.parquet.hadoop.example.ExampleParquetWriter;
-import org.apache.parquet.hadoop.util.HadoopInputFile;
-import org.apache.parquet.hadoop.util.HadoopOutputFile;
-import org.apache.parquet.schema.GroupType;
-import org.apache.parquet.schema.InvalidSchemaException;
-import org.apache.parquet.schema.Types;
-import org.junit.Assert;
-import org.junit.Rule;
-import org.junit.Test;
-
+import org.apache.parquet.bytes.HeapByteBufferAllocator;
+import org.apache.parquet.bytes.TrackingByteBufferAllocator;
 import org.apache.parquet.column.Encoding;
+import org.apache.parquet.column.ParquetProperties;
 import org.apache.parquet.column.ParquetProperties.WriterVersion;
+import org.apache.parquet.column.values.bloomfilter.BloomFilter;
 import org.apache.parquet.example.data.Group;
+import org.apache.parquet.example.data.GroupFactory;
 import org.apache.parquet.example.data.simple.SimpleGroupFactory;
+import org.apache.parquet.hadoop.example.ExampleParquetWriter;
 import org.apache.parquet.hadoop.example.GroupReadSupport;
 import org.apache.parquet.hadoop.example.GroupWriteSupport;
 import org.apache.parquet.hadoop.metadata.BlockMetaData;
 import org.apache.parquet.hadoop.metadata.ColumnChunkMetaData;
 import org.apache.parquet.hadoop.metadata.ParquetMetadata;
+import org.apache.parquet.hadoop.util.HadoopInputFile;
+import org.apache.parquet.hadoop.util.HadoopOutputFile;
 import org.apache.parquet.io.OutputFile;
 import org.apache.parquet.io.PositionOutputStream;
 import org.apache.parquet.io.api.Binary;
+import org.apache.parquet.schema.GroupType;
+import org.apache.parquet.schema.InvalidSchemaException;
 import org.apache.parquet.schema.MessageType;
+import org.apache.parquet.schema.Types;
+import org.junit.After;
+import org.junit.Assert;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 
 public class TestParquetWriter {
@@ -111,13 +113,24 @@ public class TestParquetWriter {
     }
   }
 
+  private TrackingByteBufferAllocator allocator;
+
+  @Before
+  public void initAllocator() {
+    allocator = TrackingByteBufferAllocator.wrap(new HeapByteBufferAllocator());
+  }
+
+  @After
+  public void closeAllocator() {
+    allocator.close();
+  }
+
   @Test
   public void test() throws Exception {
     Configuration conf = new Configuration();
     Path root = new Path("target/tests/TestParquetWriter/");
     enforceEmptyDir(conf, root);
-    MessageType schema = parseMessageType(
-        "message test { "
+    MessageType schema = parseMessageType("message test { "
         + "required binary binary_field; "
         + "required int32 int32_field; "
         + "required int64 int64_field; "
@@ -138,6 +151,7 @@ public class TestParquetWriter {
       for (WriterVersion version : WriterVersion.values()) {
         Path file = new Path(root, version.name() + "_" + modulo);
         ParquetWriter<Group> writer = ExampleParquetWriter.builder(new TestOutputFile(file, conf))
+            .withAllocator(allocator)
             .withCompressionCodec(UNCOMPRESSED)
             .withRowGroupSize(1024)
             .withPageSize(1024)
@@ -148,8 +162,7 @@ public class TestParquetWriter {
             .withConf(conf)
             .build();
         for (int i = 0; i < 1000; i++) {
-          writer.write(
-              f.newGroup()
+          writer.write(f.newGroup()
               .append("binary_field", "test" + (i % modulo))
               .append("int32_field", 32)
               .append("int64_field", 64l)
@@ -160,18 +173,21 @@ public class TestParquetWriter {
               .append("int96_field", Binary.fromConstantByteArray(new byte[12])));
         }
         writer.close();
-        ParquetReader<Group> reader = ParquetReader.builder(new GroupReadSupport(), file).withConf(conf).build();
+        ParquetReader<Group> reader = ParquetReader.builder(new GroupReadSupport(), file)
+            .withConf(conf)
+            .build();
         for (int i = 0; i < 1000; i++) {
           Group group = reader.read();
-          assertEquals("test" + (i % modulo), group.getBinary("binary_field", 0).toStringUsingUTF8());
+          assertEquals(
+              "test" + (i % modulo),
+              group.getBinary("binary_field", 0).toStringUsingUTF8());
           assertEquals(32, group.getInteger("int32_field", 0));
           assertEquals(64l, group.getLong("int64_field", 0));
           assertEquals(true, group.getBoolean("boolean_field", 0));
           assertEquals(1.0f, group.getFloat("float_field", 0), 0.001);
           assertEquals(2.0d, group.getDouble("double_field", 0), 0.001);
           assertEquals("foo", group.getBinary("flba_field", 0).toStringUsingUTF8());
-          assertEquals(Binary.fromConstantByteArray(new byte[12]),
-              group.getInt96("int96_field",0));
+          assertEquals(Binary.fromConstantByteArray(new byte[12]), group.getInt96("int96_field", 0));
         }
         reader.close();
         ParquetMetadata footer = readFooter(conf, file, NO_FILTER);
@@ -186,9 +202,10 @@ public class TestParquetWriter {
             }
           }
         }
-        assertEquals("Object model property should be example",
-            "example", footer.getFileMetaData().getKeyValueMetaData()
-                .get(ParquetWriter.OBJECT_MODEL_NAME_PROP));
+        assertEquals(
+            "Object model property should be example",
+            "example",
+            footer.getFileMetaData().getKeyValueMetaData().get(ParquetWriter.OBJECT_MODEL_NAME_PROP));
       }
     }
   }
@@ -201,9 +218,10 @@ public class TestParquetWriter {
     final File file = temp.newFile("test.parquet");
     file.delete();
 
-    TestUtils.assertThrows("Should reject a schema with an empty group",
-        InvalidSchemaException.class, (Callable<Void>) () -> {
+    TestUtils.assertThrows(
+        "Should reject a schema with an empty group", InvalidSchemaException.class, (Callable<Void>) () -> {
           ExampleParquetWriter.builder(new Path(file.toString()))
+              .withAllocator(allocator)
               .withType(Types.buildMessage()
                   .addField(new GroupType(REQUIRED, "invalid_group"))
                   .named("invalid_message"))
@@ -211,15 +229,18 @@ public class TestParquetWriter {
           return null;
         });
 
-    Assert.assertFalse("Should not create a file when schema is rejected",
-        file.exists());
+    Assert.assertFalse("Should not create a file when schema is rejected", file.exists());
   }
 
   // Testing the issue of PARQUET-1531 where writing null nested rows leads to empty pages if the page row count limit
   // is reached.
   @Test
   public void testNullValuesWithPageRowLimit() throws IOException {
-    MessageType schema = Types.buildMessage().optionalList().optionalElement(BINARY).as(stringType()).named("str_list")
+    MessageType schema = Types.buildMessage()
+        .optionalList()
+        .optionalElement(BINARY)
+        .as(stringType())
+        .named("str_list")
         .named("msg");
     final int recordCount = 100;
     Configuration conf = new Configuration();
@@ -232,6 +253,7 @@ public class TestParquetWriter {
     file.delete();
     Path path = new Path(file.getAbsolutePath());
     try (ParquetWriter<Group> writer = ExampleParquetWriter.builder(path)
+        .withAllocator(allocator)
         .withPageRowCountLimit(10)
         .withConf(conf)
         .build()) {
@@ -240,7 +262,8 @@ public class TestParquetWriter {
       }
     }
 
-    try (ParquetReader<Group> reader = ParquetReader.builder(new GroupReadSupport(), path).build()) {
+    try (ParquetReader<Group> reader =
+        ParquetReader.builder(new GroupReadSupport(), path).build()) {
       int readRecordCount = 0;
       for (Group group = reader.read(); group != null; group = reader.read()) {
         assertEquals(listNull.toString(), group.toString());
@@ -252,8 +275,11 @@ public class TestParquetWriter {
 
   @Test
   public void testParquetFileWithBloomFilter() throws IOException {
-    MessageType schema = Types.buildMessage().
-      required(BINARY).as(stringType()).named("name").named("msg");
+    MessageType schema = Types.buildMessage()
+        .required(BINARY)
+        .as(stringType())
+        .named("name")
+        .named("msg");
 
     String[] testNames = {"hello", "parquet", "bloom", "filter"};
     Configuration conf = new Configuration();
@@ -264,11 +290,12 @@ public class TestParquetWriter {
     file.delete();
     Path path = new Path(file.getAbsolutePath());
     try (ParquetWriter<Group> writer = ExampleParquetWriter.builder(path)
-      .withPageRowCountLimit(10)
-      .withConf(conf)
-      .withDictionaryEncoding(false)
-      .withBloomFilterEnabled("name", true)
-      .build()) {
+        .withAllocator(allocator)
+        .withPageRowCountLimit(10)
+        .withConf(conf)
+        .withDictionaryEncoding(false)
+        .withBloomFilterEnabled("name", true)
+        .build()) {
       for (String testName : testNames) {
         writer.write(factory.newGroup().append("name", testName));
       }
@@ -277,91 +304,198 @@ public class TestParquetWriter {
     try (ParquetFileReader reader = ParquetFileReader.open(HadoopInputFile.fromPath(path, new Configuration()))) {
       BlockMetaData blockMetaData = reader.getFooter().getBlocks().get(0);
       BloomFilter bloomFilter = reader.getBloomFilterDataReader(blockMetaData)
-        .readBloomFilter(blockMetaData.getColumns().get(0));
+          .readBloomFilter(blockMetaData.getColumns().get(0));
 
       for (String name : testNames) {
         assertTrue(bloomFilter.findHash(
-          LongHashFunction.xx(0).hashBytes(Binary.fromString(name).toByteBuffer())));
+            LongHashFunction.xx(0).hashBytes(Binary.fromString(name).toByteBuffer())));
       }
     }
   }
 
   @Test
   public void testParquetFileWithBloomFilterWithFpp() throws IOException {
-    int totalCount = 100000;
-    double[] testFpp = {0.01, 0.05, 0.10, 0.15, 0.20, 0.25};
+    int buildBloomFilterCount = 100000;
+    double[] testFpps = {0.01, 0.05, 0.10, 0.15, 0.20, 0.25};
     int randomStrLen = 12;
+    final int testBloomFilterCount = 200000;
 
-    Set<String> distinctStrings = new HashSet<>();
-    while (distinctStrings.size() < totalCount) {
+    Set<String> distinctStringsForFileGenerate = new HashSet<>();
+    while (distinctStringsForFileGenerate.size() < buildBloomFilterCount) {
       String str = RandomStringUtils.randomAlphabetic(randomStrLen);
-      distinctStrings.add(str);
+      distinctStringsForFileGenerate.add(str);
     }
 
-    MessageType schema = Types.buildMessage().
-      required(BINARY).as(stringType()).named("name").named("msg");
+    MessageType schema = Types.buildMessage()
+        .required(BINARY)
+        .as(stringType())
+        .named("name")
+        .named("msg");
 
     Configuration conf = new Configuration();
     GroupWriteSupport.setSchema(schema, conf);
 
     GroupFactory factory = new SimpleGroupFactory(schema);
-    for (int i = 0; i < testFpp.length; i++) {
+    for (double testFpp : testFpps) {
       File file = temp.newFile();
       file.delete();
       Path path = new Path(file.getAbsolutePath());
       try (ParquetWriter<Group> writer = ExampleParquetWriter.builder(path)
-        .withPageRowCountLimit(10)
+          .withAllocator(allocator)
+          .withPageRowCountLimit(10)
+          .withConf(conf)
+          .withDictionaryEncoding(false)
+          .withBloomFilterEnabled("name", true)
+          .withBloomFilterNDV("name", buildBloomFilterCount)
+          .withBloomFilterFPP("name", testFpp)
+          .build()) {
+        for (String str : distinctStringsForFileGenerate) {
+          writer.write(factory.newGroup().append("name", str));
+        }
+      }
+
+      try (ParquetFileReader reader =
+          ParquetFileReader.open(HadoopInputFile.fromPath(path, new Configuration()))) {
+        BlockMetaData blockMetaData = reader.getFooter().getBlocks().get(0);
+        BloomFilter bloomFilter = reader.getBloomFilterDataReader(blockMetaData)
+            .readBloomFilter(blockMetaData.getColumns().get(0));
+
+        // The false positive counts the number of times FindHash returns true.
+        int falsePositive = 0;
+        Set<String> distinctStringsForProbe = new HashSet<>();
+        while (distinctStringsForProbe.size() < testBloomFilterCount) {
+          String str = RandomStringUtils.randomAlphabetic(randomStrLen - 1);
+          if (distinctStringsForProbe.add(str)
+              && bloomFilter.findHash(LongHashFunction.xx(0)
+                  .hashBytes(Binary.fromString(str).toByteBuffer()))) {
+            falsePositive++;
+          }
+        }
+        // The false positive should be less than totalCount * fpp. Add 15% here for error space.
+        double expectedFalsePositiveMaxCount = Math.floor(testBloomFilterCount * (testFpp * 1.15));
+        assertTrue(falsePositive < expectedFalsePositiveMaxCount && falsePositive > 0);
+      }
+    }
+  }
+
+  /**
+   * If `parquet.bloom.filter.max.bytes` is set, the bytes size of bloom filter should not
+   * be larger than this value
+   */
+  @Test
+  public void testBloomFilterMaxBytesSize() throws IOException {
+    Set<String> distinctStrings = new HashSet<>();
+    while (distinctStrings.size() < 1000) {
+      String str = RandomStringUtils.randomAlphabetic(10);
+      distinctStrings.add(str);
+    }
+    int maxBloomFilterBytes = 1024 * 1024 + 1;
+    MessageType schema = Types.buildMessage()
+        .required(BINARY)
+        .as(stringType())
+        .named("name")
+        .named("msg");
+    Configuration conf = new Configuration();
+    GroupWriteSupport.setSchema(schema, conf);
+    GroupFactory factory = new SimpleGroupFactory(schema);
+    File file = temp.newFile();
+    file.delete();
+    Path path = new Path(file.getAbsolutePath());
+    try (ParquetWriter<Group> writer = ExampleParquetWriter.builder(path)
+        .withAllocator(allocator)
         .withConf(conf)
         .withDictionaryEncoding(false)
         .withBloomFilterEnabled("name", true)
-        .withBloomFilterNDV("name", totalCount)
-        .withBloomFilterFPP("name", testFpp[i])
+        .withMaxBloomFilterBytes(maxBloomFilterBytes)
         .build()) {
-        java.util.Iterator<String> iterator = distinctStrings.iterator();
-        while (iterator.hasNext()) {
-          writer.write(factory.newGroup().append("name", iterator.next()));
-        }
+      java.util.Iterator<String> iterator = distinctStrings.iterator();
+      while (iterator.hasNext()) {
+        writer.write(factory.newGroup().append("name", iterator.next()));
       }
-      distinctStrings.clear();
-
-      try (ParquetFileReader reader = ParquetFileReader.open(HadoopInputFile.fromPath(path, new Configuration()))) {
-        BlockMetaData blockMetaData = reader.getFooter().getBlocks().get(0);
-        BloomFilter bloomFilter = reader.getBloomFilterDataReader(blockMetaData)
+    }
+    try (ParquetFileReader reader = ParquetFileReader.open(HadoopInputFile.fromPath(path, new Configuration()))) {
+      BlockMetaData blockMetaData = reader.getFooter().getBlocks().get(0);
+      BloomFilter bloomFilter = reader.getBloomFilterDataReader(blockMetaData)
           .readBloomFilter(blockMetaData.getColumns().get(0));
-
-        // The exist counts the number of times FindHash returns true.
-        int exist = 0;
-        while (distinctStrings.size() < totalCount) {
-          String str = RandomStringUtils.randomAlphabetic(randomStrLen - 2);
-          if (distinctStrings.add(str) &&
-            bloomFilter.findHash(LongHashFunction.xx(0).hashBytes(Binary.fromString(str).toByteBuffer()))) {
-            exist++;
-          }
-        }
-        // The exist should be less than totalCount * fpp. Add 10% here for error space.
-        assertTrue(exist < totalCount * (testFpp[i] * 1.1) && exist > 0);
-      }
+      assertEquals(bloomFilter.getBitsetSize(), maxBloomFilterBytes);
     }
   }
 
   @Test
   public void testParquetFileWritesExpectedNumberOfBlocks() throws IOException {
-    testParquetFileNumberOfBlocks(ParquetProperties.DEFAULT_MINIMUM_RECORD_COUNT_FOR_CHECK,
-                                  ParquetProperties.DEFAULT_MAXIMUM_RECORD_COUNT_FOR_CHECK,
-                                  1);
+    testParquetFileNumberOfBlocks(
+        ParquetProperties.DEFAULT_MINIMUM_RECORD_COUNT_FOR_CHECK,
+        ParquetProperties.DEFAULT_MAXIMUM_RECORD_COUNT_FOR_CHECK,
+        1);
     testParquetFileNumberOfBlocks(1, 1, 3);
-
   }
 
-  private void testParquetFileNumberOfBlocks(int minRowCountForPageSizeCheck,
-                                             int maxRowCountForPageSizeCheck,
-                                             int expectedNumberOfBlocks) throws IOException {
-    MessageType schema = Types
-      .buildMessage()
-      .required(BINARY)
-      .as(stringType())
-      .named("str")
-      .named("msg");
+  @Test
+  public void testExtraMetaData() throws Exception {
+    final Configuration conf = new Configuration();
+    final File testDir = temp.newFile();
+    testDir.delete();
+
+    final MessageType schema = parseMessageType("message test { required int32 int32_field; }");
+    GroupWriteSupport.setSchema(schema, conf);
+    final SimpleGroupFactory f = new SimpleGroupFactory(schema);
+
+    for (WriterVersion version : WriterVersion.values()) {
+      final Path filePath = new Path(testDir.getAbsolutePath(), version.name());
+      final ParquetWriter<Group> writer = ExampleParquetWriter.builder(new TestOutputFile(filePath, conf))
+          .withConf(conf)
+          .withExtraMetaData(ImmutableMap.of("simple-key", "some-value-1", "nested.key", "some-value-2"))
+          .build();
+      for (int i = 0; i < 1000; i++) {
+        writer.write(f.newGroup().append("int32_field", 32));
+      }
+      writer.close();
+
+      final ParquetFileReader reader =
+          ParquetFileReader.open(HadoopInputFile.fromPath(filePath, new Configuration()));
+      assertEquals(1000, reader.readNextRowGroup().getRowCount());
+      assertEquals(
+          ImmutableMap.of(
+              "simple-key",
+              "some-value-1",
+              "nested.key",
+              "some-value-2",
+              ParquetWriter.OBJECT_MODEL_NAME_PROP,
+              "example"),
+          reader.getFileMetaData().getKeyValueMetaData());
+
+      reader.close();
+    }
+  }
+
+  @Test
+  public void testFailsOnConflictingExtraMetaDataKey() throws Exception {
+    final Configuration conf = new Configuration();
+    final File testDir = temp.newFile();
+    testDir.delete();
+
+    final MessageType schema = parseMessageType("message test { required int32 int32_field; }");
+    GroupWriteSupport.setSchema(schema, conf);
+
+    for (WriterVersion version : WriterVersion.values()) {
+      final Path filePath = new Path(testDir.getAbsolutePath(), version.name());
+
+      Assert.assertThrows(IllegalArgumentException.class, () -> ExampleParquetWriter.builder(
+              new TestOutputFile(filePath, conf))
+          .withConf(conf)
+          .withExtraMetaData(ImmutableMap.of(ParquetWriter.OBJECT_MODEL_NAME_PROP, "some-value-3"))
+          .build());
+    }
+  }
+
+  private void testParquetFileNumberOfBlocks(
+      int minRowCountForPageSizeCheck, int maxRowCountForPageSizeCheck, int expectedNumberOfBlocks)
+      throws IOException {
+    MessageType schema = Types.buildMessage()
+        .required(BINARY)
+        .as(stringType())
+        .named("str")
+        .named("msg");
 
     Configuration conf = new Configuration();
     GroupWriteSupport.setSchema(schema, conf);
@@ -370,13 +504,14 @@ public class TestParquetWriter {
     temp.delete();
     Path path = new Path(file.getAbsolutePath());
     try (ParquetWriter<Group> writer = ExampleParquetWriter.builder(path)
-      .withConf(conf)
-      // Set row group size to 1, to make sure we flush every time
-      // minRowCountForPageSizeCheck or maxRowCountForPageSizeCheck is exceeded
-      .withRowGroupSize(1)
-      .withMinRowCountForPageSizeCheck(minRowCountForPageSizeCheck)
-      .withMaxRowCountForPageSizeCheck(maxRowCountForPageSizeCheck)
-      .build()) {
+        .withAllocator(allocator)
+        .withConf(conf)
+        // Set row group size to 1, to make sure we flush every time
+        // minRowCountForPageSizeCheck or maxRowCountForPageSizeCheck is exceeded
+        .withRowGroupSize(1)
+        .withMinRowCountForPageSizeCheck(minRowCountForPageSizeCheck)
+        .withMaxRowCountForPageSizeCheck(maxRowCountForPageSizeCheck)
+        .build()) {
 
       SimpleGroupFactory factory = new SimpleGroupFactory(schema);
       writer.write(factory.newGroup().append("str", "foo"));
